@@ -11,6 +11,9 @@
 #  License for the specific language governing permissions and limitations
 #  under the License.
 
+import os
+import sys
+
 import eventlet
 
 # NOTE(dims): monkey patch subprocess to prevent failures in latest eventlet
@@ -22,6 +25,11 @@ except TypeError:
 
 # -- General configuration ----------------------------------------------------
 
+# If extensions (or modules to document with autodoc) are in another directory,
+# add these directories to sys.path here. If the directory is relative to the
+# documentation root, use os.path.abspath to make it absolute, like shown here.
+sys.path.insert(0, os.path.join(os.path.abspath('.'), '_exts'))
+
 # Add any Sphinx extension module names here, as strings. They can be
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom ones.
 extensions = ['sphinx.ext.viewcode',
@@ -30,10 +38,12 @@ extensions = ['sphinx.ext.viewcode',
               'sphinxcontrib.pecanwsme.rest',
               'sphinxcontrib.seqdiag',
               'sphinxcontrib.apidoc',
+              'sphinxcontrib.rsvgconverter',
               'oslo_config.sphinxext',
               'oslo_config.sphinxconfiggen',
               'oslo_policy.sphinxext',
               'oslo_policy.sphinxpolicygen',
+              'automated_steps',
               ]
 
 try:
@@ -54,9 +64,7 @@ apidoc_excluded_paths = [
 apidoc_separate_modules = True
 
 repository_name = 'openstack/ironic'
-bug_project = '943'
-bug_tag = ''
-html_last_updated_fmt = '%Y-%m-%d %H:%M'
+use_storyboard = True
 
 wsme_protocols = ['restjson']
 
@@ -74,7 +82,6 @@ source_suffix = '.rst'
 master_doc = 'index'
 
 # General information about the project.
-project = u'Ironic'
 copyright = u'OpenStack Foundation'
 
 config_generator_config_file = '../../tools/config/ironic-config-generator.conf'
@@ -83,17 +90,6 @@ sample_config_basename = '_static/ironic'
 policy_generator_config_file = '../../tools/policy/ironic-policy-generator.conf'
 sample_policy_basename = '_static/ironic'
 
-# The version info for the project you're documenting, acts as replacement for
-# |version| and |release|, also used in various other places throughout the
-# built documents.
-#
-# The short X.Y version.
-from ironic import version as ironic_version
-# The full version, including alpha/beta/rc tags.
-release = ironic_version.version_info.release_string()
-# The short X.Y version.
-version = ironic_version.version_info.version_string()
-
 # A list of ignored prefixes for module index sorting.
 modindex_common_prefix = ['ironic.']
 
@@ -128,8 +124,9 @@ else:
     html_theme = 'default'
 
 # Output file base name for HTML help builder.
-htmlhelp_basename = '%sdoc' % project
+htmlhelp_basename = 'Ironicdoc'
 
+latex_use_xindy = False
 
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass
@@ -137,13 +134,16 @@ htmlhelp_basename = '%sdoc' % project
 latex_documents = [
     (
         'index',
-        '%s.tex' % project,
-        u'%s Documentation' % project,
+        'doc-ironic.tex',
+        u'Ironic Documentation',
         u'OpenStack Foundation',
         'manual'
     ),
 ]
 
+# Allow deeper levels of nesting for \begin...\end stanzas
+latex_elements = {'maxlistdepth': 10}
+
 # -- Options for seqdiag ------------------------------------------------------
 
 seqdiag_html_image_format = "SVG"
