@@ -14,12 +14,12 @@
 #    under the License.
 
 from ironic_lib import metrics_utils
-import pecan
 from pecan import rest
 from six.moves import http_client
 import wsme
 from wsme import types as wtypes
 
+from ironic import api
 from ironic.api.controllers import base
 from ironic.api.controllers import link
 from ironic.api.controllers.v1 import types
@@ -79,6 +79,10 @@ def hide_fields_in_newer_versions(obj):
         obj.default_rescue_interface = wsme.Unset
         obj.enabled_rescue_interfaces = wsme.Unset
 
+    if not api_utils.allow_bios_interface():
+        obj.default_bios_interface = wsme.Unset
+        obj.enabled_bios_interfaces = wsme.Unset
+
 
 class Driver(base.APIBase):
     """API representation of a driver."""
@@ -99,6 +103,7 @@ class Driver(base.APIBase):
     """A list containing links to driver properties"""
 
     """Default interface for a hardware type"""
+    default_bios_interface = wtypes.text
     default_boot_interface = wtypes.text
     default_console_interface = wtypes.text
     default_deploy_interface = wtypes.text
@@ -112,6 +117,7 @@ class Driver(base.APIBase):
     default_vendor_interface = wtypes.text
 
     """A list of enabled interfaces for a hardware type"""
+    enabled_bios_interfaces = [wtypes.text]
     enabled_boot_interfaces = [wtypes.text]
     enabled_console_interfaces = [wtypes.text]
     enabled_deploy_interfaces = [wtypes.text]
@@ -125,14 +131,11 @@ class Driver(base.APIBase):
     enabled_vendor_interfaces = [wtypes.text]
 
     @staticmethod
-    def convert_with_links(name, hosts, driver_type, detail=False,
-                           interface_info=None):
+    def convert_with_links(name, hosts, detail=False, interface_info=None):
         """Convert driver/hardware type info to an API-serializable object.
 
-        :param name: name of driver or hardware type.
+        :param name: name of a hardware type.
         :param hosts: list of conductor hostnames driver is active on.
-        :param driver_type: 'classic' for classic drivers, 'dynamic' for
-                            hardware types.
         :param detail: boolean, whether to include detailed info, such as
                        the 'type' field and default/enabled interfaces fields.
         :param interface_info: optional list of dicts of hardware interface
@@ -144,30 +147,32 @@ class Driver(base.APIBase):
         driver.hosts = hosts
         driver.links = [
             link.Link.make_link('self',
-                                pecan.request.public_url,
+                                api.request.public_url,
                                 'drivers', name),
             link.Link.make_link('bookmark',
-                                pecan.request.public_url,
+                                api.request.public_url,
                                 'drivers', name,
                                 bookmark=True)
         ]
         if api_utils.allow_links_node_states_and_driver_properties():
             driver.properties = [
                 link.Link.make_link('self',
-                                    pecan.request.public_url,
+                                    api.request.public_url,
                                     'drivers', name + "/properties"),
                 link.Link.make_link('bookmark',
-                                    pecan.request.public_url,
+                                    api.request.public_url,
                                     'drivers', name + "/properties",
                                     bookmark=True)
             ]
 
         if api_utils.allow_dynamic_drivers():
-            driver.type = driver_type
-            if driver_type == 'dynamic' and detail:
+            # NOTE(dtantsur): only dynamic drivers (based on hardware types)
+            # are supported starting with the Rocky release.
+            driver.type = 'dynamic'
+            if detail:
                 if interface_info is None:
                     # TODO(jroll) objectify this
-                    interface_info = (pecan.request.dbapi
+                    interface_info = (api.request.dbapi
                                       .list_hardware_type_interfaces([name]))
                 for iface_type in driver_base.ALL_INTERFACES:
                     default = None
@@ -186,12 +191,6 @@ class Driver(base.APIBase):
                     setattr(driver, default_key, default)
                     setattr(driver, enabled_key, list(enabled))
 
-            elif detail:
-                for iface_type in driver_base.ALL_INTERFACES:
-                    # always return None for classic drivers
-                    setattr(driver, 'default_%s_interface' % iface_type, None)
-                    setattr(driver, 'enabled_%s_interfaces' % iface_type, None)
-
         hide_fields_in_newer_versions(driver)
         return driver
 
@@ -217,10 +216,9 @@ class DriverList(base.APIBase):
     """A list containing drivers objects"""
 
     @staticmethod
-    def convert_with_links(drivers, hardware_types, detail=False):
+    def convert_with_links(hardware_types, detail=False):
         """Convert drivers and hardware types to an API-serializable object.
 
-        :param drivers: dict mapping driver names to conductor hostnames.
         :param hardware_types: dict mapping hardware type names to conductor
                                hostnames.
         :param detail: boolean, whether to include detailed info, such as
@@ -228,17 +226,14 @@ class DriverList(base.APIBase):
         :returns: an API-serializable driver collection object.
         """
         collection = DriverList()
-        collection.drivers = [
-            Driver.convert_with_links(dname, list(drivers[dname]), 'classic',
-                                      detail=detail)
-            for dname in drivers]
+        collection.drivers = []
 
         # NOTE(jroll) we return hardware types in all API versions,
         # but restrict type/default/enabled fields to 1.30.
         # This is checked in Driver.convert_with_links(), however also
         # checking here can save us a DB query.
         if api_utils.allow_dynamic_drivers() and detail:
-            iface_info = pecan.request.dbapi.list_hardware_type_interfaces(
+            iface_info = api.request.dbapi.list_hardware_type_interfaces(
                 list(hardware_types))
         else:
             iface_info = []
@@ -249,7 +244,7 @@ class DriverList(base.APIBase):
             collection.drivers.append(
                 Driver.convert_with_links(htname,
                                           list(hardware_types[htname]),
-                                          'dynamic', detail=detail,
+                                          detail=detail,
                                           interface_info=interface_info))
         return collection
 
@@ -283,13 +278,13 @@ class DriverPassthruController(rest.RestController):
         :raises: DriverNotFound if the driver name is invalid or the
                  driver cannot be loaded.
         """
-        cdict = pecan.request.context.to_policy_values()
+        cdict = api.request.context.to_policy_values()
         policy.authorize('baremetal:driver:vendor_passthru', cdict, cdict)
 
         if driver_name not in _VENDOR_METHODS:
-            topic = pecan.request.rpcapi.get_topic_for_driver(driver_name)
-            ret = pecan.request.rpcapi.get_driver_vendor_passthru_methods(
-                pecan.request.context, driver_name, topic=topic)
+            topic = api.request.rpcapi.get_topic_for_driver(driver_name)
+            ret = api.request.rpcapi.get_driver_vendor_passthru_methods(
+                api.request.context, driver_name, topic=topic)
             _VENDOR_METHODS[driver_name] = ret
 
         return _VENDOR_METHODS[driver_name]
@@ -305,10 +300,10 @@ class DriverPassthruController(rest.RestController):
                        implementation.
         :param data: body of data to supply to the specified method.
         """
-        cdict = pecan.request.context.to_policy_values()
+        cdict = api.request.context.to_policy_values()
         policy.authorize('baremetal:driver:vendor_passthru', cdict, cdict)
 
-        topic = pecan.request.rpcapi.get_topic_for_driver(driver_name)
+        topic = api.request.rpcapi.get_topic_for_driver(driver_name)
         return api_utils.vendor_passthru(driver_name, method, topic, data=data,
                                          driver_passthru=True)
 
@@ -334,7 +329,7 @@ class DriverRaidController(rest.RestController):
         :raises: DriverNotFound, if driver is not loaded on any of the
             conductors.
         """
-        cdict = pecan.request.context.to_policy_values()
+        cdict = api.request.context.to_policy_values()
         policy.authorize('baremetal:driver:get_raid_logical_disk_properties',
                          cdict, cdict)
 
@@ -342,10 +337,10 @@ class DriverRaidController(rest.RestController):
             raise exception.NotAcceptable()
 
         if driver_name not in _RAID_PROPERTIES:
-            topic = pecan.request.rpcapi.get_topic_for_driver(driver_name)
+            topic = api.request.rpcapi.get_topic_for_driver(driver_name)
             try:
-                info = pecan.request.rpcapi.get_raid_logical_disk_properties(
-                    pecan.request.context, driver_name, topic=topic)
+                info = api.request.rpcapi.get_raid_logical_disk_properties(
+                    api.request.context, driver_name, topic=topic)
             except exception.UnsupportedDriverExtension as e:
                 # Change error code as 404 seems appropriate because RAID is a
                 # standard interface and all drivers might not have it.
@@ -376,7 +371,7 @@ class DriversController(rest.RestController):
         #              will break from a single-line doc string.
         #              This is a result of a bug in sphinxcontrib-pecanwsme
         # https://github.com/dreamhost/sphinxcontrib-pecanwsme/issues/8
-        cdict = pecan.request.context.to_policy_values()
+        cdict = api.request.context.to_policy_values()
         policy.authorize('baremetal:driver:get', cdict, cdict)
 
         api_utils.check_allow_driver_detail(detail)
@@ -386,14 +381,13 @@ class DriversController(rest.RestController):
                 '"type" filter must be one of "classic" or "dynamic", '
                 'if specified.'))
 
-        driver_list = {}
-        hw_type_dict = {}
-        if type is None or type == 'classic':
-            driver_list = pecan.request.dbapi.get_active_driver_dict()
         if type is None or type == 'dynamic':
-            hw_type_dict = pecan.request.dbapi.get_active_hardware_type_dict()
-        return DriverList.convert_with_links(driver_list, hw_type_dict,
-                                             detail=detail)
+            hw_type_dict = api.request.dbapi.get_active_hardware_type_dict()
+        else:
+            # NOTE(dtantsur): we don't support classic drivers starting with
+            # the Rocky release.
+            hw_type_dict = {}
+        return DriverList.convert_with_links(hw_type_dict, detail=detail)
 
     @METRICS.timer('DriversController.get_one')
     @expose.expose(Driver, wtypes.text)
@@ -403,23 +397,14 @@ class DriversController(rest.RestController):
         # retrieving a list of drivers using the current sqlalchemy schema, but
         # this path must be exposed for Pecan to route any paths we might
         # choose to expose below it.
-        cdict = pecan.request.context.to_policy_values()
+        cdict = api.request.context.to_policy_values()
         policy.authorize('baremetal:driver:get', cdict, cdict)
 
-        def _find_driver(driver_dict, driver_type):
-            for name, hosts in driver_dict.items():
-                if name == driver_name:
-                    return Driver.convert_with_links(name, list(hosts),
-                                                     driver_type, detail=True)
-
-        hw_type_dict = pecan.request.dbapi.get_active_hardware_type_dict()
-        driver = _find_driver(hw_type_dict, 'dynamic')
-        if driver:
-            return driver
-        driver_dict = pecan.request.dbapi.get_active_driver_dict()
-        driver = _find_driver(driver_dict, 'classic')
-        if driver:
-            return driver
+        hw_type_dict = api.request.dbapi.get_active_hardware_type_dict()
+        for name, hosts in hw_type_dict.items():
+            if name == driver_name:
+                return Driver.convert_with_links(name, list(hosts),
+                                                 detail=True)
 
         raise exception.DriverNotFound(driver_name=driver_name)
 
@@ -434,13 +419,13 @@ class DriversController(rest.RestController):
         :raises: DriverNotFound (HTTP 404) if the driver name is invalid or
                  the driver cannot be loaded.
         """
-        cdict = pecan.request.context.to_policy_values()
+        cdict = api.request.context.to_policy_values()
         policy.authorize('baremetal:driver:get_properties', cdict, cdict)
 
         if driver_name not in _DRIVER_PROPERTIES:
-            topic = pecan.request.rpcapi.get_topic_for_driver(driver_name)
-            properties = pecan.request.rpcapi.get_driver_properties(
-                pecan.request.context, driver_name, topic=topic)
+            topic = api.request.rpcapi.get_topic_for_driver(driver_name)
+            properties = api.request.rpcapi.get_driver_properties(
+                api.request.context, driver_name, topic=topic)
             _DRIVER_PROPERTIES[driver_name] = properties
 
         return _DRIVER_PROPERTIES[driver_name]
