@@ -94,6 +94,8 @@ BASE_VERSION = 1
 # v1.54: Add events support.
 # v1.55: Add deploy templates API.
 # v1.56: Add support for building configdrives.
+# v1.57: Add support for updating an exisiting allocation.
+# v1.58: Add support for backfilling allocations.
 
 MINOR_0_JUNO = 0
 MINOR_1_INITIAL_VERSION = 1
@@ -152,6 +154,8 @@ MINOR_53_PORT_SMARTNIC = 53
 MINOR_54_EVENTS = 54
 MINOR_55_DEPLOY_TEMPLATES = 55
 MINOR_56_BUILD_CONFIGDRIVE = 56
+MINOR_57_ALLOCATION_UPDATE = 57
+MINOR_58_ALLOCATION_BACKFILL = 58
 
 # When adding another version, update:
 # - MINOR_MAX_VERSION
@@ -159,7 +163,7 @@ MINOR_56_BUILD_CONFIGDRIVE = 56
 #   explanation of what changed in the new version
 # - common/release_mappings.py, RELEASE_MAPPING['master']['api']
 
-MINOR_MAX_VERSION = MINOR_56_BUILD_CONFIGDRIVE
+MINOR_MAX_VERSION = MINOR_58_ALLOCATION_BACKFILL
 
 # String representations of the minor and maximum versions
 _MIN_VERSION_STRING = '{}.{}'.format(BASE_VERSION, MINOR_1_INITIAL_VERSION)
