@@ -21,11 +21,9 @@ Based on pecan.middleware.errordocument
 """
 
 import json
-from xml import etree as et
 
 from oslo_log import log
 import six
-import webob
 
 from ironic.common.i18n import _
 
@@ -71,27 +69,12 @@ class ParsableErrorMiddleware(object):
 
         app_iter = self.app(environ, replacement_start_response)
         if (state['status_code'] // 100) not in (2, 3):
-            req = webob.Request(environ)
-            if (req.accept.best_match(['application/json', 'application/xml'])
-                == 'application/xml'):
-                try:
-                    # simple check xml is valid
-                    body = [et.ElementTree.tostring(
-                            et.ElementTree.fromstring('<error_message>'
-                                                      + '\n'.join(app_iter)
-                                                      + '</error_message>'))]
-                except et.ElementTree.ParseError as err:
-                    LOG.error('Error parsing HTTP response: %s', err)
-                    body = ['<error_message>%s' % state['status_code']
-                            + '</error_message>']
-                state['headers'].append(('Content-Type', 'application/xml'))
-            else:
-                if six.PY3:
-                    app_iter = [i.decode('utf-8') for i in app_iter]
-                body = [json.dumps({'error_message': '\n'.join(app_iter)})]
-                if six.PY3:
-                    body = [item.encode('utf-8') for item in body]
-                state['headers'].append(('Content-Type', 'application/json'))
+            if six.PY3:
+                app_iter = [i.decode('utf-8') for i in app_iter]
+            body = [json.dumps({'error_message': '\n'.join(app_iter)})]
+            if six.PY3:
+                body = [item.encode('utf-8') for item in body]
+            state['headers'].append(('Content-Type', 'application/json'))
             state['headers'].append(('Content-Length', str(len(body[0]))))
         else:
             body = app_iter
