@@ -10,6 +10,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import copy
+
 from neutronclient.common import exceptions as neutron_exceptions
 from neutronclient.v2_0 import client as clientv20
 from oslo_log import log
@@ -48,8 +50,7 @@ def _get_neutron_session():
     if not _NEUTRON_SESSION:
         _NEUTRON_SESSION = keystone.get_session(
             'neutron',
-            # TODO(pas-ha) remove in Rocky
-            timeout=CONF.neutron.timeout or CONF.neutron.url_timeout)
+            timeout=CONF.neutron.timeout)
     return _NEUTRON_SESSION
 
 
@@ -63,22 +64,8 @@ def get_client(token=None, context=None):
     session = _get_neutron_session()
     service_auth = keystone.get_auth('neutron')
 
-    # TODO(pas-ha) remove in Rocky, always simply load from config
-    # 'noauth' then would correspond to 'auth_type=none' and
-    # 'endpoint_override'
-    adapter_params = {}
-    if (CONF.neutron.auth_strategy == 'noauth'
-            and CONF.neutron.auth_type is None):
-        CONF.set_override('auth_type', 'none', group='neutron')
-        if not CONF.neutron.endpoint_override:
-            adapter_params['endpoint_override'] = (CONF.neutron.url
-                                                   or DEFAULT_NEUTRON_URL)
-    else:
-        if CONF.neutron.url and not CONF.neutron.endpoint_override:
-            adapter_params['endpoint_override'] = CONF.neutron.url
-    adapter = keystone.get_adapter('neutron', session=session,
-                                   auth=service_auth, **adapter_params)
-    endpoint = adapter.get_endpoint()
+    endpoint = keystone.get_endpoint('neutron', session=session,
+                                     auth=service_auth)
 
     user_auth = None
     if CONF.neutron.auth_type != 'none' and context.auth_token:
@@ -185,21 +172,24 @@ def _verify_security_groups(security_groups, client):
         return
     try:
         neutron_sec_groups = (
-            client.list_security_groups().get('security_groups', []))
+            client.list_security_groups(id=security_groups, fields='id').get(
+                'security_groups', []))
     except neutron_exceptions.NeutronClientException as e:
         msg = (_("Could not retrieve security groups from neutron: %(exc)s") %
                {'exc': e})
         LOG.exception(msg)
         raise exception.NetworkError(msg)
 
-    existing_sec_groups = [sec_group['id'] for sec_group in neutron_sec_groups]
-    missing_sec_groups = set(security_groups) - set(existing_sec_groups)
-    if missing_sec_groups:
-        msg = (_('Could not find these security groups (specified via ironic '
-                 'config) in neutron: %(ir-sg)s')
-               % {'ir-sg': list(missing_sec_groups)})
-        LOG.error(msg)
-        raise exception.NetworkError(msg)
+    if set(security_groups).issubset(x['id'] for x in neutron_sec_groups):
+        return
+
+    missing_sec_groups = set(security_groups).difference(
+        x['id'] for x in neutron_sec_groups)
+    msg = (_('Could not find these security groups (specified via ironic '
+             'config) in neutron: %(ir-sg)s')
+           % {'ir-sg': list(missing_sec_groups)})
+    LOG.error(msg)
+    raise exception.NetworkError(msg)
 
 
 def add_ports_to_network(task, network_uuid, security_groups=None):
@@ -208,6 +198,10 @@ def add_ports_to_network(task, network_uuid, security_groups=None):
     Create neutron ports for each pxe_enabled port on task.node to boot
     the ramdisk.
 
+    If the config option 'neutron.add_all_ports' is set, neutron ports
+    for non-pxe-enabled ports are also created -- these neutron ports
+    will not have any assigned IP addresses.
+
     :param task: a TaskManager instance.
     :param network_uuid: UUID of a neutron network where ports will be
         created.
@@ -218,6 +212,7 @@ def add_ports_to_network(task, network_uuid, security_groups=None):
     """
     client = get_client(context=task.context)
     node = task.node
+    add_all_ports = CONF.neutron.add_all_ports
 
     # If Security Groups are specified, verify that they exist
     _verify_security_groups(security_groups, client)
@@ -226,6 +221,7 @@ def add_ports_to_network(task, network_uuid, security_groups=None):
               '%(network_uuid)s using %(net_iface)s network interface.',
               {'net_iface': task.driver.network.__class__.__name__,
                'node': node.uuid, 'network_uuid': network_uuid})
+
     body = {
         'port': {
             'network_id': network_uuid,
@@ -246,21 +242,35 @@ def add_ports_to_network(task, network_uuid, security_groups=None):
     ports = {}
     failures = []
     portmap = get_node_portmap(task)
-    pxe_enabled_ports = [p for p in task.ports if p.pxe_enabled]
 
-    if not pxe_enabled_ports:
+    if not add_all_ports:
+        ports_to_create = [p for p in task.ports if p.pxe_enabled]
+    else:
+        ports_to_create = task.ports
+    if not ports_to_create:
+        pxe_enabled = 'PXE-enabled ' if not add_all_ports else ''
         raise exception.NetworkError(_(
-            "No available PXE-enabled port on node %s.") % node.uuid)
+            "No available %(enabled)sports on node %(node)s.") %
+            {'enabled': pxe_enabled, 'node': node.uuid})
 
-    for ironic_port in pxe_enabled_ports:
+    for ironic_port in ports_to_create:
+        # Start with a clean state for each port
+        port_body = copy.deepcopy(body)
         # Skip ports that are missing required information for deploy.
         if not validate_port_info(node, ironic_port):
             failures.append(ironic_port.uuid)
             continue
-        body['port']['mac_address'] = ironic_port.address
+        port_body['port']['mac_address'] = ironic_port.address
         binding_profile = {'local_link_information':
                            [portmap[ironic_port.uuid]]}
-        body['port']['binding:profile'] = binding_profile
+        port_body['port']['binding:profile'] = binding_profile
+
+        if not ironic_port.pxe_enabled:
+            LOG.debug("Adding port %(port)s to network %(net)s for "
+                      "provisioning without an IP allocation.",
+                      {'port': ironic_port.uuid,
+                       'net': network_uuid})
+            port_body['fixed_ips'] = []
 
         is_smart_nic = is_smartnic_port(ironic_port)
         if is_smart_nic:
@@ -269,21 +279,22 @@ def add_ports_to_network(task, network_uuid, security_groups=None):
                       'port %(port_id)s, hostname %(hostname)s',
                       {'port_id': ironic_port.uuid,
                        'hostname': link_info['hostname']})
-            body['port']['binding:host_id'] = link_info['hostname']
+            port_body['port']['binding:host_id'] = link_info['hostname']
 
             # TODO(hamdyk): use portbindings.VNIC_SMARTNIC from neutron-lib
-            body['port']['binding:vnic_type'] = VNIC_SMARTNIC
+            port_body['port']['binding:vnic_type'] = VNIC_SMARTNIC
         client_id = ironic_port.extra.get('client-id')
         if client_id:
             client_id_opt = {'opt_name': DHCP_CLIENT_ID,
                              'opt_value': client_id}
-            extra_dhcp_opts = body['port'].get('extra_dhcp_opts', [])
+            extra_dhcp_opts = port_body['port'].get('extra_dhcp_opts', [])
             extra_dhcp_opts.append(client_id_opt)
-            body['port']['extra_dhcp_opts'] = extra_dhcp_opts
+            port_body['port']['extra_dhcp_opts'] = extra_dhcp_opts
         try:
             if is_smart_nic:
-                wait_for_host_agent(client, body['port']['binding:host_id'])
-            port = client.create_port(body)
+                wait_for_host_agent(client,
+                                    port_body['port']['binding:host_id'])
+            port = client.create_port(port_body)
             if is_smart_nic:
                 wait_for_port_status(client, port['port']['id'], 'ACTIVE')
         except neutron_exceptions.NeutronClientException as e:
@@ -297,11 +308,11 @@ def add_ports_to_network(task, network_uuid, security_groups=None):
             ports[ironic_port.uuid] = port['port']['id']
 
     if failures:
-        if len(failures) == len(pxe_enabled_ports):
+        if len(failures) == len(ports_to_create):
             rollback_ports(task, network_uuid)
             raise exception.NetworkError(_(
-                "Failed to create neutron ports for any PXE enabled port "
-                "on node %s.") % node.uuid)
+                "Failed to create neutron ports for node's %(node)s ports "
+                "%(ports)s.") % {'node': node.uuid, 'ports': ports_to_create})
         else:
             LOG.warning("Some errors were encountered when updating "
                         "vif_port_id for node %(node)s on "
@@ -322,7 +333,11 @@ def remove_ports_from_network(task, network_uuid):
     :param network_uuid: UUID of a neutron network ports will be deleted from.
     :raises: NetworkError
     """
-    macs = [p.address for p in task.ports if p.pxe_enabled]
+    add_all_ports = CONF.neutron.add_all_ports
+    if not add_all_ports:
+        macs = [p.address for p in task.ports if p.pxe_enabled]
+    else:
+        macs = [p.address for p in task.ports]
     if macs:
         params = {
             'network_id': network_uuid,
