@@ -19,6 +19,7 @@ import eventlet
 import futurist
 from futurist import periodics
 from futurist import rejection
+from ironic_lib import mdns
 from oslo_db import exception as db_exception
 from oslo_log import log
 from oslo_utils import excutils
@@ -39,6 +40,7 @@ from ironic.conductor import task_manager
 from ironic.conf import CONF
 from ironic.db import api as dbapi
 from ironic.drivers import base as driver_base
+from ironic.drivers.modules import deploy_utils
 from ironic import objects
 from ironic.objects import fields as obj_fields
 
@@ -78,6 +80,7 @@ class BaseConductorManager(object):
         self.sensors_notifier = rpc.get_sensors_notifier()
         self._started = False
         self._shutdown = None
+        self._zeroconf = None
 
     def init_host(self, admin_context=None):
         """Initialize the conductor host.
@@ -114,11 +117,6 @@ class BaseConductorManager(object):
             use_groups=self._use_groups())
         """Consistent hash ring which maps drivers to conductors."""
 
-        # TODO(dtantsur): remove in Stein
-        if CONF.enabled_drivers:
-            raise RuntimeError("The enabled_drivers configuration option "
-                               "no longer has any effect and must be empty")
-
         _check_enabled_interfaces()
 
         # NOTE(deva): these calls may raise DriverLoadError or DriverNotFound
@@ -212,6 +210,9 @@ class BaseConductorManager(object):
         except exception.NoFreeConductorWorker:
             LOG.warning('Failed to start worker for resuming allocations.')
 
+        if CONF.conductor.enable_mdns:
+            self._publish_endpoint()
+
         self._started = True
 
     def _use_groups(self):
@@ -316,6 +317,11 @@ class BaseConductorManager(object):
         self._periodic_tasks.stop()
         self._periodic_tasks.wait()
         self._executor.shutdown(wait=True)
+
+        if self._zeroconf is not None:
+            self._zeroconf.close()
+            self._zeroconf = None
+
         self._started = False
 
     def _register_and_validate_hardware_interfaces(self, hardware_types):
@@ -427,9 +433,7 @@ class BaseConductorManager(object):
         except exception.DriverNotFound:
             return False
 
-        return self.host in ring.get_nodes(
-            node_uuid.encode('utf-8'),
-            replicas=CONF.hash_distribution_replicas)
+        return self.host in ring.get_nodes(node_uuid.encode('utf-8'))
 
     def _fail_if_in_state(self, context, filters, provision_state,
                           sort_key, callback_method=None,
@@ -442,29 +446,29 @@ class BaseConductorManager(object):
         in whatever provisioning activity it was currently doing.
         That failure is processed here.
 
-        :param: context: request context
-        :param: filters: criteria (as a dictionary) to get the desired
-                         list of nodes that satisfy the filter constraints.
-                         For example, if filters['provisioned_before'] = 60,
-                         this would process nodes whose provision_updated_at
-                         field value was 60 or more seconds before 'now'.
-        :param: provision_state: provision_state that the node is in,
-                                 for the provisioning activity to have failed,
-                                 either one string or a set.
-        :param: sort_key: the nodes are sorted based on this key.
-        :param: callback_method: the callback method to be invoked in a
-                                 spawned thread, for a failed node. This
-                                 method must take a :class:`TaskManager` as
-                                 the first (and only required) parameter.
-        :param: err_handler: for a failed node, the error handler to invoke
-                             if an error occurs trying to spawn an thread
-                             to do the callback_method.
-        :param: last_error: the error message to be updated in node.last_error
-        :param: keep_target_state: if True, a failed node will keep the same
-                                   target provision state it had before the
-                                   failure. Otherwise, the node's target
-                                   provision state will be determined by the
-                                   fsm.
+        :param context: request context
+        :param filters: criteria (as a dictionary) to get the desired
+                        list of nodes that satisfy the filter constraints.
+                        For example, if filters['provisioned_before'] = 60,
+                        this would process nodes whose provision_updated_at
+                        field value was 60 or more seconds before 'now'.
+        :param provision_state: provision_state that the node is in,
+                                for the provisioning activity to have failed,
+                                either one string or a set.
+        :param sort_key: the nodes are sorted based on this key.
+        :param callback_method: the callback method to be invoked in a
+                                spawned thread, for a failed node. This
+                                method must take a :class:`TaskManager` as
+                                the first (and only required) parameter.
+        :param err_handler: for a failed node, the error handler to invoke
+                            if an error occurs trying to spawn an thread
+                            to do the callback_method.
+        :param last_error: the error message to be updated in node.last_error
+        :param keep_target_state: if True, a failed node will keep the same
+                                  target provision state it had before the
+                                  failure. Otherwise, the node's target
+                                  provision state will be determined by the
+                                  fsm.
 
         """
         if isinstance(provision_state, six.string_types):
@@ -508,7 +512,7 @@ class BaseConductorManager(object):
     def _start_consoles(self, context):
         """Start consoles if set enabled.
 
-        :param: context: request context
+        :param context: request context
         """
         filters = {'console_enabled': True}
 
@@ -566,3 +570,12 @@ class BaseConductorManager(object):
         for allocation in objects.Allocation.list(context, filters=filters):
             LOG.debug('Resuming unfinished allocation %s', allocation.uuid)
             allocations.do_allocate(context, allocation)
+
+    def _publish_endpoint(self):
+        params = {}
+        if CONF.debug:
+            params['ipa_debug'] = True
+        self._zeroconf = mdns.Zeroconf()
+        self._zeroconf.register_service('baremetal',
+                                        deploy_utils.get_ironic_api_url(),
+                                        params=params)
