@@ -29,6 +29,7 @@ from ironic.common import exception
 from ironic.common import faults
 from ironic.common.i18n import _
 from ironic.common import network
+from ironic.common import nova
 from ironic.common import states
 from ironic.conductor import notification_utils as notify_utils
 from ironic.conductor import task_manager
@@ -271,6 +272,10 @@ def node_power_action(task, new_state, timeout=None):
     if node['target_power_state'] != target_state:
         node['target_power_state'] = target_state
         node['last_error'] = None
+        driver_internal_info = node.driver_internal_info
+        driver_internal_info['last_power_state_change'] = str(
+            timeutils.utcnow().isoformat())
+        node.driver_internal_info = driver_internal_info
         node.save()
 
     # take power action
@@ -304,6 +309,9 @@ def node_power_action(task, new_state, timeout=None):
         node['power_state'] = target_state
         node['target_power_state'] = states.NOSTATE
         node.save()
+        if node.instance_uuid:
+            nova.power_update(
+                task.context, node.instance_uuid, target_state)
         notify_utils.emit_power_set_notification(
             task, fields.NotificationLevel.INFO, fields.NotificationStatus.END,
             new_state)
@@ -385,6 +393,8 @@ def cleaning_error_handler(task, msg, tear_down_cleaning=True,
                            set_fail_state=True):
     """Put a failed node in CLEANFAIL and maintenance."""
     node = task.node
+    node.fault = faults.CLEAN_FAILURE
+    node.maintenance = True
 
     if tear_down_cleaning:
         try:
@@ -402,17 +412,19 @@ def cleaning_error_handler(task, msg, tear_down_cleaning=True,
         # Clear clean step, msg should already include current step
         node.clean_step = {}
         info = node.driver_internal_info
+        # Clear any leftover metadata about cleaning
         info.pop('clean_step_index', None)
-        # Clear any leftover metadata about cleaning reboots
         info.pop('cleaning_reboot', None)
+        info.pop('cleaning_polling', None)
+        info.pop('skip_current_clean_step', None)
         node.driver_internal_info = info
     # For manual cleaning, the target provision state is MANAGEABLE, whereas
     # for automated cleaning, it is AVAILABLE.
     manual_clean = node.target_provision_state == states.MANAGEABLE
     node.last_error = msg
-    node.maintenance = True
-    node.maintenance_reason = msg
-    node.fault = faults.CLEAN_FAILURE
+    # NOTE(dtantsur): avoid overwriting existing maintenance_reason
+    if not node.maintenance_reason:
+        node.maintenance_reason = msg
     node.save()
 
     if set_fail_state and node.provision_state != states.CLEANFAIL:
@@ -460,9 +472,11 @@ def deploying_error_handler(task, logmsg, errmsg, traceback=False,
         # in node.driver_internal_info for debugging purposes.
         node.deploy_step = {}
         info = node.driver_internal_info
+        # Clear any leftover metadata about deployment.
         info.pop('deploy_step_index', None)
-        # Clear any leftover metadata about deployment reboots
         info.pop('deployment_reboot', None)
+        info.pop('deployment_polling', None)
+        info.pop('skip_current_deploy_step', None)
         node.driver_internal_info = info
 
     if cleanup_err:
@@ -862,6 +876,22 @@ def fast_track_able(task):
             and task.node.last_error is None)
 
 
+def value_within_timeout(value, timeout):
+    """Checks if the time is within the previous timeout seconds from now.
+
+    :param value: a string representing date and time or None.
+    :param timeout: timeout in seconds.
+    """
+    # use native datetime objects for conversion and compare
+    # slightly odd because py2 compatability :(
+    last = datetime.datetime.strptime(value or '1970-01-01T00:00:00.000000',
+                                      "%Y-%m-%dT%H:%M:%S.%f")
+    # If we found nothing, we assume that the time is essentially epoch.
+    time_delta = datetime.timedelta(seconds=timeout)
+    last_valid = timeutils.utcnow() - time_delta
+    return last_valid <= last
+
+
 def is_fast_track(task):
     """Checks a fast track is available.
 
@@ -874,23 +904,12 @@ def is_fast_track(task):
     within the timeout set by [deploy]fast_track_timeout and the power
     state for the machine is POWER_ON, then fast track is permitted.
 
-    :param node: A node object.
+    :param task: Taskmanager object
     :returns: True if the last heartbeat that was recorded was within
               the [deploy]fast_track_timeout setting.
     """
-    if not fast_track_able(task):
-        return False
-    # use native datetime objects for conversion and compare
-    # slightly odd because py2 compatability :(
-    last = datetime.datetime.strptime(
-        task.node.driver_internal_info.get(
-            'agent_last_heartbeat',
-            '1970-01-01T00:00:00.000000'),
-        "%Y-%m-%dT%H:%M:%S.%f")
-    # If we found nothing, we assume that the time is essentially epoch.
-    time_delta = datetime.timedelta(seconds=CONF.deploy.fast_track_timeout)
-    last_valid = timeutils.utcnow() - time_delta
-    # Checking the power state, because if we find the machine off due to
-    # any action, we can't actually fast track the node. :(
-    return (last_valid <= last
+    return (fast_track_able(task)
+            and value_within_timeout(
+                task.node.driver_internal_info.get('agent_last_heartbeat'),
+                CONF.deploy.fast_track_timeout)
             and task.driver.power.get_power_state(task) == states.POWER_ON)
