@@ -76,7 +76,7 @@ opts = [
                default='/tftpboot/master_images',
                help=_('On ironic-conductor node, directory where master TFTP '
                       'images are stored on disk. '
-                      'Setting to <None> disables image caching.')),
+                      'Setting to the empty string disables image caching.')),
     cfg.IntOpt('dir_permission',
                help=_("The permission that will be applied to the TFTP "
                       "folders upon creation. This should be set to the "
@@ -126,6 +126,16 @@ opts = [
                default=0,
                help=_('Timeout value (in seconds) for downloading an image '
                       'via iPXE. Defaults to 0 (no timeout)')),
+    cfg.IntOpt('boot_retry_timeout',
+               min=60,
+               help=_('Timeout (in seconds) after which PXE boot should be '
+                      'retried. Must be less than [conductor]'
+                      'deploy_callback_timeout. Disabled by default.')),
+    cfg.IntOpt('boot_retry_check_interval',
+               default=90, min=1,
+               help=_('Interval (in seconds) between periodic checks on PXE '
+                      'boot retry. Has no effect if boot_retry_timeout '
+                      'is not set.')),
     cfg.StrOpt('ip_version',
                default='4',
                choices=[('4', _('IPv4')),
