@@ -97,6 +97,20 @@ class Connection(object):
                          (asc, desc)
         """
 
+    @abc.abstractmethod
+    def check_node_list(self, idents):
+        """Check a list of node identities and map it to UUIDs.
+
+        This call takes a list of node names and/or UUIDs and tries to convert
+        them to UUIDs. It fails early if any identities cannot possible be used
+        as names or UUIDs.
+
+        :param idents: List of identities.
+        :returns: A mapping from requests identities to node UUIDs.
+        :raises: NodeNotFound if some identities were not found or cannot be
+            valid names or UUIDs.
+        """
+
     @abc.abstractmethod
     def reserve_node(self, tag, node_id):
         """Reserve a node.
@@ -549,8 +563,16 @@ class Connection(object):
         """
 
     @abc.abstractmethod
-    def get_offline_conductors(self):
-        """Get a list conductor hostnames that are offline (dead).
+    def get_offline_conductors(self, field='hostname'):
+        """Get a list conductors that are offline (dead).
+
+        :param field: A field to return, hostname by default.
+        :returns: A list of requested fields of offline conductors.
+        """
+
+    @abc.abstractmethod
+    def get_online_conductors(self):
+        """Get a list conductor hostnames that are online and active.
 
         :returns: A list of conductor hostnames.
         """
@@ -902,13 +924,14 @@ class Connection(object):
         """
 
     @abc.abstractmethod
-    def check_versions(self):
+    def check_versions(self, ignore_models=()):
         """Checks the whole database for incompatible objects.
 
         This scans all the tables in search of objects that are not supported;
         i.e., those that are not specified in
         `ironic.common.release_mappings.RELEASE_MAPPING`.
 
+        :param ignore_models: List of model names to skip.
         :returns: A Boolean. True if all the objects have supported versions;
                   False otherwise.
         """
@@ -1078,3 +1101,194 @@ class Connection(object):
         :returns: A list of BIOSSetting objects.
         :raises: NodeNotFound if the node is not found.
         """
+
+    @abc.abstractmethod
+    def get_allocation_by_id(self, allocation_id):
+        """Return an allocation representation.
+
+        :param allocation_id: The id of an allocation.
+        :returns: An allocation.
+        :raises: AllocationNotFound
+        """
+
+    @abc.abstractmethod
+    def get_allocation_by_uuid(self, allocation_uuid):
+        """Return an allocation representation.
+
+        :param allocation_uuid: The uuid of an allocation.
+        :returns: An allocation.
+        :raises: AllocationNotFound
+        """
+
+    @abc.abstractmethod
+    def get_allocation_by_name(self, name):
+        """Return an allocation representation.
+
+        :param name: The logical name of an allocation.
+        :returns: An allocation.
+        :raises: AllocationNotFound
+        """
+
+    @abc.abstractmethod
+    def get_allocation_list(self, filters=None, limit=None, marker=None,
+                            sort_key=None, sort_dir=None):
+        """Return a list of allocations.
+
+        :param filters: Filters to apply. Defaults to None.
+
+                        :node_uuid: uuid of node
+                        :state: allocation state
+                        :resource_class: requested resource class
+        :param limit: Maximum number of allocations to return.
+        :param marker: The last item of the previous page; we return the next
+                       result set.
+        :param sort_key: Attribute by which results should be sorted.
+        :param sort_dir: Direction in which results should be sorted.
+                         (asc, desc)
+        :returns: A list of allocations.
+        """
+
+    @abc.abstractmethod
+    def create_allocation(self, values):
+        """Create a new allocation.
+
+        :param values: Dict of values to create an allocation with
+        :returns: An allocation
+        :raises: AllocationDuplicateName
+        :raises: AllocationAlreadyExists
+        """
+
+    @abc.abstractmethod
+    def update_allocation(self, allocation_id, values, update_node=True):
+        """Update properties of an allocation.
+
+        :param allocation_id: Allocation ID
+        :param values: Dict of values to update.
+        :param update_node: If True and node_id is updated, update the node
+            with instance_uuid and traits from the allocation
+        :returns: An allocation.
+        :raises: AllocationNotFound
+        :raises: AllocationDuplicateName
+        :raises: InstanceAssociated
+        :raises: NodeAssociated
+        """
+
+    @abc.abstractmethod
+    def take_over_allocation(self, allocation_id, old_conductor_id,
+                             new_conductor_id):
+        """Do a take over for an allocation.
+
+        The allocation is only updated if the old conductor matches the
+        provided value, thus guarding against races.
+
+        :param allocation_id: Allocation ID
+        :param old_conductor_id: The conductor ID we expect to be the current
+            ``conductor_affinity`` of the allocation.
+        :param new_conductor_id: The conductor ID of the new
+            ``conductor_affinity``.
+        :returns: True if the take over was successful, False otherwise.
+        :raises: AllocationNotFound
+        """
+
+    @abc.abstractmethod
+    def destroy_allocation(self, allocation_id):
+        """Destroy an allocation.
+
+        :param allocation_id: Allocation ID
+        :raises: AllocationNotFound
+        """
+
+    @abc.abstractmethod
+    def create_deploy_template(self, values):
+        """Create a deployment template.
+
+        :param values: A dict describing the deployment template. For example:
+
+                     ::
+
+                      {
+                       'uuid': uuidutils.generate_uuid(),
+                       'name': 'CUSTOM_DT1',
+                      }
+        :raises: DeployTemplateDuplicateName if a deploy template with the same
+            name exists.
+        :raises: DeployTemplateAlreadyExists if a deploy template with the same
+            UUID exists.
+        :returns: A deploy template.
+        """
+
+    @abc.abstractmethod
+    def update_deploy_template(self, template_id, values):
+        """Update a deployment template.
+
+        :param template_id: ID of the deployment template to update.
+        :param values: A dict describing the deployment template. For example:
+
+                     ::
+
+                      {
+                       'uuid': uuidutils.generate_uuid(),
+                       'name': 'CUSTOM_DT1',
+                      }
+        :raises: DeployTemplateDuplicateName if a deploy template with the same
+            name exists.
+        :raises: DeployTemplateNotFound if the deploy template does not exist.
+        :returns: A deploy template.
+        """
+
+    @abc.abstractmethod
+    def destroy_deploy_template(self, template_id):
+        """Destroy a deployment template.
+
+        :param template_id: ID of the deployment template to destroy.
+        :raises: DeployTemplateNotFound if the deploy template does not exist.
+        """
+
+    @abc.abstractmethod
+    def get_deploy_template_by_id(self, template_id):
+        """Retrieve a deployment template by ID.
+
+        :param template_id: ID of the deployment template to retrieve.
+        :raises: DeployTemplateNotFound if the deploy template does not exist.
+        :returns: A deploy template.
+        """
+
+    @abc.abstractmethod
+    def get_deploy_template_by_uuid(self, template_uuid):
+        """Retrieve a deployment template by UUID.
+
+        :param template_uuid: UUID of the deployment template to retrieve.
+        :raises: DeployTemplateNotFound if the deploy template does not exist.
+        :returns: A deploy template.
+        """
+
+    @abc.abstractmethod
+    def get_deploy_template_by_name(self, template_name):
+        """Retrieve a deployment template by name.
+
+        :param template_name: name of the deployment template to retrieve.
+        :raises: DeployTemplateNotFound if the deploy template does not exist.
+        :returns: A deploy template.
+        """
+
+    @abc.abstractmethod
+    def get_deploy_template_list(self, limit=None, marker=None,
+                                 sort_key=None, sort_dir=None):
+        """Retrieve a list of deployment templates.
+
+        :param limit: Maximum number of deploy templates to return.
+        :param marker: The last item of the previous page; we return the next
+                       result set.
+        :param sort_key: Attribute by which results should be sorted.
+        :param sort_dir: Direction in which results should be sorted.
+                         (asc, desc)
+        :returns: A list of deploy templates.
+        """
+
+    @abc.abstractmethod
+    def get_deploy_template_list_by_names(self, names):
+        """Return a list of deployment templates with one of a list of names.
+
+        :param names: List of names to filter by.
+        :returns: A list of deploy templates.
+        """
