@@ -179,6 +179,10 @@ class Node(Base):
     protected = Column(Boolean, nullable=False, default=False,
                        server_default=false())
     protected_reason = Column(Text, nullable=True)
+    owner = Column(String(255), nullable=True)
+    allocation_id = Column(Integer, ForeignKey('allocations.id'),
+                           nullable=True)
+    description = Column(Text, nullable=True)
 
     bios_interface = Column(String(255), nullable=True)
     boot_interface = Column(String(255), nullable=True)
@@ -212,6 +216,7 @@ class Port(Base):
     pxe_enabled = Column(Boolean, default=True)
     internal_info = Column(db_types.JsonEncodedDict)
     physical_network = Column(String(64), nullable=True)
+    is_smartnic = Column(Boolean, nullable=True, default=False)
 
 
 class Portgroup(Base):
@@ -322,6 +327,69 @@ class BIOSSetting(Base):
     value = Column(Text, nullable=True)
 
 
+class Allocation(Base):
+    """Represents an allocation of a node for deployment."""
+
+    __tablename__ = 'allocations'
+    __table_args__ = (
+        schema.UniqueConstraint('name', name='uniq_allocations0name'),
+        schema.UniqueConstraint('uuid', name='uniq_allocations0uuid'),
+        table_args())
+    id = Column(Integer, primary_key=True)
+    uuid = Column(String(36), nullable=False)
+    name = Column(String(255), nullable=True)
+    node_id = Column(Integer, ForeignKey('nodes.id'), nullable=True)
+    state = Column(String(15), nullable=False)
+    last_error = Column(Text, nullable=True)
+    resource_class = Column(String(80), nullable=True)
+    traits = Column(db_types.JsonEncodedList)
+    candidate_nodes = Column(db_types.JsonEncodedList)
+    extra = Column(db_types.JsonEncodedDict)
+    # The last conductor to handle this allocation (internal field).
+    conductor_affinity = Column(Integer, ForeignKey('conductors.id'),
+                                nullable=True)
+
+
+class DeployTemplate(Base):
+    """Represents a deployment template."""
+
+    __tablename__ = 'deploy_templates'
+    __table_args__ = (
+        schema.UniqueConstraint('uuid', name='uniq_deploytemplates0uuid'),
+        schema.UniqueConstraint('name', name='uniq_deploytemplates0name'),
+        table_args())
+    id = Column(Integer, primary_key=True)
+    uuid = Column(String(36))
+    name = Column(String(255), nullable=False)
+    extra = Column(db_types.JsonEncodedDict)
+
+
+class DeployTemplateStep(Base):
+    """Represents a deployment step in a deployment template."""
+
+    __tablename__ = 'deploy_template_steps'
+    __table_args__ = (
+        Index('deploy_template_id', 'deploy_template_id'),
+        Index('deploy_template_steps_interface_idx', 'interface'),
+        Index('deploy_template_steps_step_idx', 'step'),
+        table_args())
+    id = Column(Integer, primary_key=True)
+    deploy_template_id = Column(Integer, ForeignKey('deploy_templates.id'),
+                                nullable=False)
+    interface = Column(String(255), nullable=False)
+    step = Column(String(255), nullable=False)
+    args = Column(db_types.JsonEncodedDict, nullable=False)
+    priority = Column(Integer, nullable=False)
+    deploy_template = orm.relationship(
+        "DeployTemplate",
+        backref='steps',
+        primaryjoin=(
+            'and_(DeployTemplateStep.deploy_template_id == '
+            'DeployTemplate.id)'),
+        foreign_keys=deploy_template_id
+    )
+
+
 def get_class(model_name):
     """Returns the model class with the specified name.
 
