@@ -38,6 +38,41 @@ LOG = logging.getLogger(__name__)
 RAID_CONFIG_SCHEMA = os.path.join(os.path.dirname(__file__),
                                   'raid_config_schema.json')
 
+RAID_APPLY_CONFIGURATION_ARGSINFO = {
+    "raid_config": {
+        "description": "The RAID configuration to apply.",
+        "required": True,
+    },
+    "create_root_volume": {
+        "description": (
+            "Setting this to 'False' indicates not to create root "
+            "volume that is specified in 'raid_config'. Default "
+            "value is 'True'."
+        ),
+        "required": False,
+    },
+    "create_nonroot_volumes": {
+        "description": (
+            "Setting this to 'False' indicates not to create "
+            "non-root volumes (all except the root volume) in "
+            "'raid_config'. Default value is 'True'."
+        ),
+        "required": False,
+    },
+    "delete_existing": {
+        "description": (
+            "Setting this to 'True' indicates to delete existing RAID "
+            "configuration prior to creating the new configuration. "
+            "Default value is 'True'."
+        ),
+        "required": False,
+    }
+}
+"""
+This may be used as the deploy_step argsinfo argument for RAID interfaces
+implementing an apply_configuration deploy step.
+"""
+
 
 class BareDriver(object):
     """A bare driver object which will have interfaces attached later.
@@ -965,6 +1000,89 @@ class ManagementInterface(BaseInterface):
         raise exception.UnsupportedDriverExtension(
             driver=task.node.driver, extension='inject_nmi')
 
+    def get_supported_indicators(self, task, component=None):
+        """Get a map of the supported indicators (e.g. LEDs).
+
+        :param task: A task from TaskManager.
+        :param component: If not `None`, return indicator information
+            for just this component, otherwise return indicators for
+            all existing components.
+        :returns: A dictionary of hardware components
+            (:mod:`ironic.common.components`) as keys with values
+            being dictionaries having indicator IDs as keys and indicator
+            properties as values.
+
+            ::
+
+                {
+                    'chassis': {
+                        'enclosure-0': {
+                            "readonly": true,
+                            "states": [
+                                "off",
+                                "on"
+                            ]
+                        }
+                    },
+                    'system':
+                        'blade-A': {
+                            "readonly": true,
+                            "states": [
+                                "pff",
+                                "on"
+                            ]
+                        }
+                    },
+                    'drive':
+                        'ssd0': {
+                            "readonly": true,
+                            "states": [
+                                "off",
+                                "on"
+                            ]
+                        }
+                    }
+                }
+
+        """
+        raise exception.UnsupportedDriverExtension(
+            driver=task.node.driver, extension='get_supported_indicators')
+
+    def set_indicator_state(self, task, component, indicator, state):
+        """Set indicator on the hardware component to the desired state.
+
+        :param task: A task from TaskManager.
+        :param component: The hardware component, one of
+            :mod:`ironic.common.components`.
+        :param indicator: Indicator ID (as reported by
+            `get_supported_indicators`).
+        :state: Desired state of the indicator, one of
+            :mod:`ironic.common.indicator_states`.
+        :raises: InvalidParameterValue if an invalid component, indicator
+            or state is specified.
+        :raises: MissingParameterValue if a required parameter is missing
+        """
+        raise exception.UnsupportedDriverExtension(
+            driver=task.node.driver, extension='set_indicator_state')
+
+    def get_indicator_state(self, task, component, indicator):
+        """Get current state of the indicator of the hardware component.
+
+        :param task: A task from TaskManager.
+        :param component: The hardware component, one of
+            :mod:`ironic.common.components`.
+        :param indicator: Indicator ID (as reported by
+            `get_supported_indicators`).
+        :raises: InvalidParameterValue if an invalid component or indicator
+            is specified.
+        :raises: MissingParameterValue if a required parameter is missing
+        :returns: Current state of the indicator, one of
+            :mod:`ironic.common.indicator_states`.
+
+        """
+        raise exception.UnsupportedDriverExtension(
+            driver=task.node.driver, extension='get_indicator_state')
+
 
 class InspectInterface(BaseInterface):
     """Interface for inspection-related actions."""
@@ -1120,10 +1238,47 @@ class RAIDInterface(BaseInterface):
         """
         raid.validate_configuration(raid_config, self.raid_schema)
 
+    # NOTE(mgoddard): This is not marked as a deploy step, because it requires
+    # the create_configuration method to support use during deployment, which
+    # might not be true for all implementations. Subclasses wishing to expose
+    # an apply_configuration deploy step should implement this method with a
+    # deploy_step decorator. The RAID_APPLY_CONFIGURATION_ARGSINFO variable may
+    # be used for the deploy_step argsinfo argument. The create_configuration
+    # method must also accept a delete_existing argument.
+    def apply_configuration(self, task, raid_config, create_root_volume=True,
+                            create_nonroot_volumes=True,
+                            delete_existing=True):
+        """Applies RAID configuration on the given node.
+
+        :param task: A TaskManager instance.
+        :param raid_config: The RAID configuration to apply.
+        :param create_root_volume: Setting this to False indicates
+            not to create root volume that is specified in raid_config.
+            Default value is True.
+        :param create_nonroot_volumes: Setting this to False indicates
+            not to create non-root volumes (all except the root volume) in
+            raid_config.  Default value is True.
+        :param delete_existing: Setting this to True indicates to delete RAID
+            configuration prior to creating the new configuration.
+        :raises: InvalidParameterValue, if the RAID configuration is invalid.
+        :returns: states.DEPLOYWAIT if RAID configuration is in progress
+            asynchronously or None if it is complete.
+        """
+        self.validate_raid_config(task, raid_config)
+        node = task.node
+        node.target_raid_config = raid_config
+        node.save()
+        return self.create_configuration(
+            task,
+            create_root_volume=create_root_volume,
+            create_nonroot_volumes=create_nonroot_volumes,
+            delete_existing=delete_existing)
+
     @abc.abstractmethod
     def create_configuration(self, task,
                              create_root_volume=True,
-                             create_nonroot_volumes=True):
+                             create_nonroot_volumes=True,
+                             delete_existing=True):
         """Creates RAID configuration on the given node.
 
         This method creates a RAID configuration on the given node.
@@ -1143,8 +1298,11 @@ class RAIDInterface(BaseInterface):
         :param create_nonroot_volumes: Setting this to False indicates
             not to create non-root volumes (all except the root volume) in the
             node's target_raid_config.  Default value is True.
-        :returns: states.CLEANWAIT if RAID configuration is in progress
-            asynchronously or None if it is complete.
+        :param delete_existing: Setting this to True indicates to delete RAID
+            configuration prior to creating the new configuration.
+        :returns: states.CLEANWAIT (cleaning) or states.DEPLOYWAIT (deployment)
+            if RAID configuration is in progress asynchronously, or None if it
+            is complete.
         """
 
     @abc.abstractmethod
@@ -1156,8 +1314,9 @@ class RAIDInterface(BaseInterface):
         cleared by the implementation.
 
         :param task: A TaskManager instance.
-        :returns: states.CLEANWAIT if deletion is in progress
-            asynchronously or None if it is complete.
+        :returns: states.CLEANWAIT (cleaning) or states.DEPLOYWAIT (deployment)
+            if deletion is in progress asynchronously, or None if it is
+            complete.
         """
 
     def get_logical_disk_properties(self):
