@@ -67,11 +67,14 @@ VENDOR_PROPERTIES = {
         'older deploy ramdisks. Defaults to False. Optional.')
 }
 
-__HEARTBEAT_RECORD_ONLY = (states.ENROLL, states.MANAGEABLE,
-                           states.AVAILABLE)
+__HEARTBEAT_RECORD_ONLY = (states.ENROLL, states.MANAGEABLE, states.AVAILABLE,
+                           states.CLEANING, states.DEPLOYING, states.RESCUING)
 _HEARTBEAT_RECORD_ONLY = frozenset(__HEARTBEAT_RECORD_ONLY)
 
-_HEARTBEAT_ALLOWED = (states.DEPLOYWAIT, states.CLEANWAIT, states.RESCUEWAIT)
+_HEARTBEAT_ALLOWED = (states.DEPLOYWAIT, states.CLEANWAIT, states.RESCUEWAIT,
+                      # These are allowed but don't cause any actions since
+                      # they're also in HEARTBEAT_RECORD_ONLY.
+                      states.DEPLOYING, states.CLEANING, states.RESCUING)
 HEARTBEAT_ALLOWED = frozenset(_HEARTBEAT_ALLOWED)
 
 _FASTTRACK_HEARTBEAT_ALLOWED = (states.DEPLOYWAIT, states.CLEANWAIT,
@@ -296,6 +299,31 @@ class HeartbeatMixin(object):
             return FASTTRACK_HEARTBEAT_ALLOWED
         return HEARTBEAT_ALLOWED
 
+    def _heartbeat_in_maintenance(self, task):
+        node = task.node
+        if (node.provision_state in (states.CLEANING, states.CLEANWAIT)
+                and not CONF.conductor.allow_provisioning_in_maintenance):
+            LOG.error('Aborting cleaning for node %s, as it is in maintenance '
+                      'mode', node.uuid)
+            last_error = _('Cleaning aborted as node is in maintenance mode')
+            manager_utils.cleaning_error_handler(task, last_error)
+        elif (node.provision_state in (states.DEPLOYING, states.DEPLOYWAIT)
+              and not CONF.conductor.allow_provisioning_in_maintenance):
+            LOG.error('Aborting deployment for node %s, as it is in '
+                      'maintenance mode', node.uuid)
+            last_error = _('Deploy aborted as node is in maintenance mode')
+            deploy_utils.set_failed_state(task, last_error, collect_logs=False)
+        elif (node.provision_state in (states.RESCUING, states.RESCUEWAIT)
+              and not CONF.conductor.allow_provisioning_in_maintenance):
+            LOG.error('Aborting rescuing for node %s, as it is in '
+                      'maintenance mode', node.uuid)
+            last_error = _('Rescue aborted as node is in maintenance mode')
+            manager_utils.rescuing_error_handler(task, last_error)
+        else:
+            LOG.warning('Heartbeat from node %(node)s in '
+                        'maintenance mode; not taking any action.',
+                        {'node': node.uuid})
+
     @METRICS.timer('HeartbeatMixin.heartbeat')
     def heartbeat(self, task, callback_url, agent_version):
         """Process a heartbeat.
@@ -307,7 +335,7 @@ class HeartbeatMixin(object):
         # NOTE(pas-ha) immediately skip the rest if nothing to do
         if (task.node.provision_state not in self.heartbeat_allowed_states
             and not manager_utils.fast_track_able(task)):
-            LOG.debug('Heartbeat from node %(node)s in unsupported '
+            LOG.error('Heartbeat from node %(node)s in unsupported '
                       'provision state %(state)s, not taking any action.',
                       {'node': task.node.uuid,
                        'state': task.node.provision_state})
@@ -342,20 +370,18 @@ class HeartbeatMixin(object):
                       'node as on-line.', {'node': task.node.uuid})
             return
 
+        if node.maintenance:
+            return self._heartbeat_in_maintenance(task)
+
         # Async call backs don't set error state on their own
         # TODO(jimrollenhagen) improve error messages here
         msg = _('Failed checking if deploy is done.')
         try:
-            if node.maintenance:
-                # this shouldn't happen often, but skip the rest if it does.
-                LOG.debug('Heartbeat from node %(node)s in maintenance mode; '
-                          'not taking any action.', {'node': node.uuid})
-                return
             # NOTE(mgoddard): Only handle heartbeats during DEPLOYWAIT if we
             # are currently in the core deploy.deploy step. Other deploy steps
             # may cause the agent to boot, but we should not trigger deployment
-            # at that point.
-            elif node.provision_state == states.DEPLOYWAIT:
+            # at that point if the driver is polling for completion of a step.
+            if node.provision_state == states.DEPLOYWAIT:
                 if self.in_core_deploy_step(task):
                     if not self.deploy_has_started(task):
                         msg = _('Node failed to deploy.')
@@ -366,6 +392,14 @@ class HeartbeatMixin(object):
                     else:
                         node.touch_provisioning()
                 else:
+                    # The exceptions from RPC are not possible as we using cast
+                    # here
+                    # Check if the driver is polling for completion of a step,
+                    # via the 'deployment_polling' flag.
+                    polling = node.driver_internal_info.get(
+                        'deployment_polling', False)
+                    if not polling:
+                        manager_utils.notify_conductor_resume_deploy(task)
                     node.touch_provisioning()
             elif node.provision_state == states.CLEANWAIT:
                 node.touch_provisioning()
@@ -382,7 +416,12 @@ class HeartbeatMixin(object):
                     manager_utils.notify_conductor_resume_clean(task)
                 else:
                     msg = _('Node failed to check cleaning progress.')
-                    self.continue_cleaning(task)
+                    # Check if the driver is polling for completion of a step,
+                    # via the 'cleaning_polling' flag.
+                    polling = node.driver_internal_info.get(
+                        'cleaning_polling', False)
+                    if not polling:
+                        self.continue_cleaning(task)
             elif (node.provision_state == states.RESCUEWAIT):
                 msg = _('Node failed to perform rescue operation.')
                 self._finalize_rescue(task)
@@ -784,7 +823,7 @@ class AgentDeployMixin(HeartbeatMixin):
         logical_disks = raid_config.get('logical_disks', [])
         software_raid = False
         for logical_disk in logical_disks:
-            if logical_disk['controller'] == 'software':
+            if logical_disk.get('controller') == 'software':
                 LOG.debug('Node %s has a Software RAID configuration',
                           node.uuid)
                 software_raid = True
