@@ -277,7 +277,6 @@ def _prepare_variables(task):
     for i_key, i_value in i_info.items():
         if i_key.startswith('image_'):
             image[i_key[6:]] = i_value
-    image['mem_req'] = _calculate_memory_req(task)
 
     checksum = image.get('checksum')
     if checksum:
@@ -429,8 +428,10 @@ class AnsibleDeploy(agent_base.HeartbeatMixin, base.DeployInterface):
                   {'node': node.uuid, 'ip': node_address})
         variables = _prepare_variables(task)
         if not node.driver_internal_info.get('is_whole_disk_image'):
-            variables.update(_parse_partitioning_info(task.node))
-        playbook, user, key = _parse_ansible_driver_info(task.node)
+            variables.update(_parse_partitioning_info(node))
+        if node.target_raid_config:
+            variables.update({'raid_config': node.target_raid_config})
+        playbook, user, key = _parse_ansible_driver_info(node)
         node_list = [(node.uuid, node_address, user, node.extra)]
         extra_vars = _prepare_extra_vars(node_list, variables=variables)
 
@@ -443,9 +444,24 @@ class AnsibleDeploy(agent_base.HeartbeatMixin, base.DeployInterface):
     @task_manager.require_exclusive_lock
     def deploy(self, task):
         """Perform a deployment to a node."""
+        self._required_image_info(task)
         manager_utils.node_power_action(task, states.REBOOT)
         return states.DEPLOYWAIT
 
+    @staticmethod
+    def _required_image_info(task):
+        """Gather and save needed image info while the context is good.
+
+        Gather image info that will be needed later, during the
+        continue_deploy execution, where the context won't be the same
+        anymore, since coming from the server's heartbeat.
+        """
+        node = task.node
+        i_info = node.instance_info
+        i_info['image_mem_req'] = _calculate_memory_req(task)
+        node.instance_info = i_info
+        node.save()
+
     @METRICS.timer('AnsibleDeploy.tear_down')
     @task_manager.require_exclusive_lock
     def tear_down(self, task):
@@ -521,11 +537,18 @@ class AnsibleDeploy(agent_base.HeartbeatMixin, base.DeployInterface):
         node_address = _get_node_ip(task)
 
         node_list = [(node.uuid, node_address, user, node.extra)]
-        extra_vars = _prepare_extra_vars(node_list)
+
+        if node.target_raid_config:
+            variables = {'raid_config': node.target_raid_config}
+            extra_vars = _prepare_extra_vars(node_list, variables=variables)
+        else:
+            extra_vars = _prepare_extra_vars(node_list)
 
         LOG.debug('Starting cleaning step %(step)s on node %(node)s',
                   {'node': node.uuid, 'step': stepname})
         step_tags = step['args'].get('tags', [])
+        LOG.debug("Detected tags from cleaning step: %(tags)s",
+                  {'tags': step_tags})
         _run_playbook(node, playbook, extra_vars, key, tags=step_tags)
         LOG.info('Ansible completed cleaning step %(step)s '
                  'on node %(node)s.',
