@@ -26,6 +26,7 @@ from ironic.common import states
 from ironic.common import utils
 from ironic.drivers import base
 from ironic.drivers.modules.drac import common as drac_common
+from ironic.drivers.modules.redfish import inspect as redfish_inspect
 from ironic import objects
 
 drac_exceptions = importutils.try_import('dracclient.exceptions')
@@ -35,7 +36,18 @@ LOG = logging.getLogger(__name__)
 METRICS = metrics_utils.get_metrics_logger(__name__)
 
 
-class DracInspect(base.InspectInterface):
+class DracRedfishInspect(redfish_inspect.RedfishInspect):
+    """iDRAC Redfish interface for inspection-related actions.
+
+    Presently, this class entirely defers to its base class, a generic,
+    vendor-independent Redfish interface. Future resolution of Dell EMC-
+    specific incompatibilities and introduction of vendor value added
+    should be implemented by this class.
+    """
+    pass
+
+
+class DracWSManInspect(base.InspectInterface):
 
     def get_properties(self):
         """Return the properties of the interface.
@@ -221,3 +233,20 @@ class DracInspect(base.InspectInterface):
                     pxe_dev_nics.append(nic.id)
 
         return pxe_dev_nics
+
+
+class DracInspect(DracWSManInspect):
+    """Class alias of class DracWSManInspect.
+
+    This class provides ongoing support of the deprecated 'idrac'
+    inspect interface implementation entrypoint.
+
+    All bug fixes and new features should be implemented in its base
+    class, DracWSManInspect. That makes them available to both the
+    deprecated 'idrac' and new 'idrac-wsman' entrypoints. Such changes
+    should not be made to this class.
+    """
+
+    def __init__(self):
+        LOG.warning("Inspect interface 'idrac' is deprecated and may be "
+                    "removed in a future release. Use 'idrac-wsman' instead.")
