@@ -2,7 +2,7 @@
 #
 # Copyright 2014 Red Hat, Inc.
 # All Rights Reserved.
-# Copyright (c) 2017-2018 Dell Inc. or its subsidiaries.
+# Copyright (c) 2017-2019 Dell Inc. or its subsidiaries.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -20,6 +20,8 @@
 DRAC management interface
 """
 
+import time
+
 from ironic_lib import metrics_utils
 from oslo_log import log as logging
 from oslo_utils import importutils
@@ -28,9 +30,12 @@ from ironic.common import boot_devices
 from ironic.common import exception
 from ironic.common.i18n import _
 from ironic.conductor import task_manager
+from ironic.conf import CONF
 from ironic.drivers import base
 from ironic.drivers.modules.drac import common as drac_common
 from ironic.drivers.modules.drac import job as drac_job
+from ironic.drivers.modules.redfish import management as redfish_management
+
 
 drac_exceptions = importutils.try_import('dracclient.exceptions')
 
@@ -76,6 +81,9 @@ _NON_PERSISTENT_BOOT_MODE = 'OneTime'
 # Clear job id's constant
 _CLEAR_JOB_IDS = 'JID_CLEARALL_FORCE'
 
+# BIOS pending job constant
+_BIOS_JOB_NAME = 'BIOS.Setup.1-1'
+
 
 def _get_boot_device(node, drac_boot_devices=None):
     client = drac_common.get_drac_client(node)
@@ -183,10 +191,19 @@ def set_boot_device(node, device, persistent=False):
     :raises: DracOperationError on an error from python-dracclient.
     """
 
-    drac_job.validate_job_queue(node)
-
     client = drac_common.get_drac_client(node)
 
+    # If pending BIOS job found in job queue, we need to clear that job
+    # before executing cleaning step of management interface.
+    # Otherwise, pending BIOS config job can cause creating new config jobs
+    # to fail.
+    unfinished_jobs = drac_job.list_unfinished_jobs(node)
+    if unfinished_jobs:
+        unfinished_bios_jobs = [job.id for job in unfinished_jobs if
+                                _BIOS_JOB_NAME in job.name]
+        if unfinished_bios_jobs:
+            client.delete_jobs(job_ids=unfinished_bios_jobs)
+
     try:
         drac_boot_devices = client.list_boot_devices()
 
@@ -249,7 +266,28 @@ def set_boot_device(node, device, persistent=False):
                       "'%(device)s' for node %(node_id)s.") %
                     {'device': device, 'node_id': node.uuid})
 
-        client.commit_pending_bios_changes()
+        job_id = client.commit_pending_bios_changes()
+        job_entry = client.get_job(job_id)
+
+        timeout = CONF.drac.boot_device_job_status_timeout
+        end_time = time.time() + timeout
+
+        LOG.debug('Waiting for BIOS configuration job %(job_id)s '
+                  'to be scheduled for node %(node)s',
+                  {'job_id': job_id,
+                   'node': node.uuid})
+
+        while job_entry.status != "Scheduled":
+            if time.time() >= end_time:
+                raise exception.DracOperationError(
+                    error=_(
+                        'Timed out waiting BIOS configuration for job '
+                        '%(job)s to reach Scheduled state.  Job is still '
+                        'in %(status)s state.') %
+                    {'job': job_id, 'status': job_entry.status})
+            time.sleep(3)
+            job_entry = client.get_job(job_id)
+
     except drac_exceptions.BaseClientException as exc:
         LOG.error('DRAC driver failed to change boot device order for '
                   'node %(node_uuid)s. Reason: %(error)s.',
@@ -257,7 +295,18 @@ def set_boot_device(node, device, persistent=False):
         raise exception.DracOperationError(error=exc)
 
 
-class DracManagement(base.ManagementInterface):
+class DracRedfishManagement(redfish_management.RedfishManagement):
+    """iDRAC Redfish interface for management-related actions.
+
+    Presently, this class entirely defers to its base class, a generic,
+    vendor-independent Redfish interface. Future resolution of Dell EMC-
+    specific incompatibilities and introduction of vendor value added
+    should be implemented by this class.
+    """
+    pass
+
+
+class DracWSManManagement(base.ManagementInterface):
 
     def get_properties(self):
         """Return the properties of the interface."""
@@ -389,3 +438,40 @@ class DracManagement(base.ManagementInterface):
         client = drac_common.get_drac_client(node)
         client.reset_idrac(force=True, wait=True)
         client.delete_jobs(job_ids=[_CLEAR_JOB_IDS])
+
+    @METRICS.timer('DracManagement.clear_job_queue')
+    @base.clean_step(priority=0)
+    def clear_job_queue(self, task):
+        """Clear the job queue.
+
+        :param task: a TaskManager instance containing the node to act on.
+        :returns: None if it is completed.
+        :raises: DracOperationError on an error from python-dracclient.
+        """
+        try:
+            node = task.node
+
+            client = drac_common.get_drac_client(node)
+            client.delete_jobs(job_ids=[_CLEAR_JOB_IDS])
+        except drac_exceptions.BaseClientException as exc:
+            LOG.error('DRAC driver failed to clear the job queue for node '
+                      '%(node_uuid)s. Reason: %(error)s.',
+                      {'node_uuid': node.uuid, 'error': exc})
+            raise exception.DracOperationError(error=exc)
+
+
+class DracManagement(DracWSManManagement):
+    """Class alias of class DracWSManManagement.
+
+    This class provides ongoing support of the deprecated 'idrac'
+    management interface implementation entrypoint.
+
+    All bug fixes and new features should be implemented in its base
+    class, DracWSManManagement. That makes them available to both the
+    deprecated 'idrac' and new 'idrac-wsman' entrypoints. Such changes
+    should not be made to this class.
+    """
+
+    def __init__(self):
+        LOG.warning("Management interface 'idrac' is deprecated and may be "
+                    "removed in a future release. Use 'idrac-wsman' instead.")
