@@ -22,6 +22,7 @@ import tempfile
 
 from ironic_lib import utils as ironic_utils
 from oslo_log import log as logging
+from oslo_utils import fileutils
 from oslo_utils import importutils
 import six
 import six.moves.urllib.parse as urlparse
@@ -36,6 +37,7 @@ from ironic.common import swift
 from ironic.common import utils
 from ironic.conductor import utils as manager_utils
 from ironic.conf import CONF
+from ironic.drivers.modules import boot_mode_utils
 from ironic.drivers.modules import deploy_utils
 
 ilo_client = importutils.try_import('proliantutils.ilo.client')
@@ -95,6 +97,27 @@ BOOT_MODE_GENERIC_TO_ILO = {'bios': 'legacy', 'uefi': 'uefi'}
 BOOT_MODE_ILO_TO_GENERIC = dict(
     (v, k) for (k, v) in BOOT_MODE_GENERIC_TO_ILO.items())
 
+POST_NULL_STATE = 'Null'
+""" Node is in Null post state."""
+
+POST_UNKNOWN_STATE = "Unknown"
+""" Node is in Unknown post state."""
+
+POST_RESET_STATE = "Reset"
+""" Node is in Reset post state."""
+
+POST_POWEROFF_STATE = "PowerOff"
+""" Node is in PowerOff post state."""
+
+POST_INPOST_STATE = "InPost"
+""" Node is in InPost post state."""
+
+POST_INPOSTDISCOVERY_STATE = "InPostDiscoveryComplete"
+""" Node is in InPostDiscoveryComplete post state."""
+
+POST_FINISHEDPOST_STATE = "FinishedPost"
+""" Node is in FinishedPost post state."""
+
 
 def copy_image_to_web_server(source_file_path, destination):
     """Copies the given image to the http web server.
@@ -183,7 +206,7 @@ def remove_image_from_swift(object_name, associated_with=None):
         swift_api = swift.SwiftAPI()
         swift_api.delete_object(container, object_name)
     except exception.SwiftObjectNotFoundError as e:
-        LOG.info("Temporary object %(associated_with_msg)s"
+        LOG.info("Temporary object %(associated_with_msg)s "
                  "was already deleted from Swift. Error: %(err)s",
                  {'associated_with_msg':
                      ("associated with %s " % associated_with
@@ -483,7 +506,7 @@ def update_boot_mode(task):
     """
 
     node = task.node
-    boot_mode = deploy_utils.get_boot_mode_for_deploy(node)
+    boot_mode = boot_mode_utils.get_boot_mode_for_deploy(node)
 
     # No boot mode found. Check if default_boot_mode is defined
     if not boot_mode and (CONF.ilo.default_boot_mode in ['bios', 'uefi']):
@@ -544,15 +567,18 @@ def setup_vmedia(task, iso, ramdisk_options):
 
     :param task: a TaskManager instance containing the node to act on.
     :param iso: a bootable ISO image href to attach to. Should be either
-        of below:
-        * A Swift object - It should be of format 'swift:<object-name>'.
-          It is assumed that the image object is present in
-          CONF.ilo.swift_ilo_container;
-        * A Glance image - It should be format 'glance://<glance-image-uuid>'
-          or just <glance-image-uuid>;
-        * An HTTP URL.
+                of below:
+
+                * A Swift object - It should be of format
+                  ``swift:<object-name>``.
+                  It is assumed that the image object is present in
+                  CONF.ilo.swift_ilo_container;
+                * A Glance image - It should be format
+                  ``glance://<glance-image-uuid>``
+                  or just ``<glance-image-uuid>``;
+                * An HTTP URL.
     :param ramdisk_options: the options to be passed to the ramdisk in virtual
-        media floppy.
+                            media floppy.
     :raises: ImageCreationFailed, if it failed while creating the floppy image.
     :raises: IloOperationError, if some operation on iLO failed.
     """
@@ -575,15 +601,18 @@ def setup_vmedia_for_boot(task, boot_iso, parameters=None):
 
     :param task: a TaskManager instance containing the node to act on.
     :param boot_iso: a bootable ISO image to attach to. Should be either
-        of below:
-        * A Swift object - It should be of format 'swift:<object-name>'.
-          It is assumed that the image object is present in
-          CONF.ilo.swift_ilo_container;
-        * A Glance image - It should be format 'glance://<glance-image-uuid>'
-          or just <glance-image-uuid>;
-        * An HTTP(S) URL.
+                     of below:
+
+                     * A Swift object - It should be of format
+                       ``swift:<object-name>``.
+                       It is assumed that the image object is present in
+                       CONF.ilo.swift_ilo_container;
+                     * A Glance image - It should be format
+                       ``glance://<glance-image-uuid>``
+                       or just ``<glance-image-uuid>``;
+                     * An HTTP URL.
     :param parameters: the parameters to pass in the virtual floppy image
-        in a dictionary.  This is optional.
+                       in a dictionary.  This is optional.
     :raises: ImageCreationFailed, if it failed while creating the floppy image.
     :raises: SwiftOperationError, if any operation with Swift fails.
     :raises: IloOperationError, if attaching virtual media failed.
@@ -768,8 +797,8 @@ def verify_image_checksum(image_location, expected_checksum):
              verification fails.
     """
     try:
-        with open(image_location, 'rb') as fd:
-            actual_checksum = utils.hash_file(fd)
+        actual_checksum = fileutils.compute_file_checksum(image_location,
+                                                          algorithm='md5')
     except IOError as e:
         LOG.error("Error opening file: %(file)s", {'file': image_location})
         raise exception.ImageRefValidationFailed(image_href=image_location,
@@ -784,3 +813,26 @@ def verify_image_checksum(image_location, expected_checksum):
         LOG.error(msg)
         raise exception.ImageRefValidationFailed(image_href=image_location,
                                                  reason=msg)
+
+
+def get_server_post_state(node):
+    """Get the current state of system POST.
+
+    :param node: an ironic node object.
+    :returns: POST state of the server. The valida states are:-
+        null, Unknown, Reset, PowerOff, InPost, InPostDiscoveryComplete
+        and FinishedPost.
+    :raises: IloOperationError on an error from IloClient library.
+    :raises: IloOperationNotSupported if retrieving post state is not
+        supported on the server.
+    """
+    ilo_object = get_ilo_object(node)
+    operation = _("Get server post state for node %s.") % node.uuid
+    try:
+        return ilo_object.get_host_post_state()
+    except ilo_error.IloCommandNotSupportedError as ilo_exception:
+        raise exception.IloOperationNotSupported(operation=operation,
+                                                 error=ilo_exception)
+    except ilo_error.IloError as ilo_exception:
+        raise exception.IloOperationError(operation=operation,
+                                          error=ilo_exception)
