@@ -17,6 +17,7 @@ iLO Management Interface
 
 from ironic_lib import metrics_utils
 from oslo_log import log as logging
+from oslo_service import loopingcall
 from oslo_utils import excutils
 from oslo_utils import importutils
 import six
@@ -25,7 +26,9 @@ import six.moves.urllib.parse as urlparse
 from ironic.common import boot_devices
 from ironic.common import exception
 from ironic.common.i18n import _
+from ironic.common import states
 from ironic.conductor import task_manager
+from ironic.conductor import utils as manager_utils
 from ironic.conf import CONF
 from ironic.drivers import base
 from ironic.drivers.modules import agent_base_vendor
@@ -54,40 +57,114 @@ BOOT_DEVICE_ILO_TO_GENERIC = {
 MANAGEMENT_PROPERTIES = ilo_common.REQUIRED_PROPERTIES.copy()
 MANAGEMENT_PROPERTIES.update(ilo_common.CLEAN_PROPERTIES)
 
+_ACTIVATE_ILO_LICENSE_ARGSINFO = {
+    'ilo_license_key': {
+        'description': (
+            'The HPE iLO Advanced license key to activate enterprise '
+            'features.'
+        ),
+        'required': True
+    }
+}
 
-def _execute_ilo_clean_step(node, step, *args, **kwargs):
-    """Executes a particular clean step.
+_RESET_ILO_CREDENTIALS_ARGSINFO = {
+    'ilo_password': {
+        'description': (
+            'Password string for iLO user with administrative privileges '
+            'being set in the driver_info property "ilo_username".'
+        ),
+        'required': True
+    }
+}
+
+_FIRMWARE_UPDATE_ARGSINFO = {
+    'firmware_update_mode': {
+        'description': (
+            "This argument indicates the mode (or mechanism) of firmware "
+            "update procedure. Supported value is 'ilo'."
+        ),
+        'required': True
+    },
+    'firmware_images': {
+        'description': (
+            "This argument represents the ordered list of JSON "
+            "dictionaries of firmware images. Each firmware image "
+            "dictionary consists of three mandatory fields, namely 'url', "
+            "'checksum' and 'component'. These fields represent firmware "
+            "image location URL, md5 checksum of image file and firmware "
+            "component type respectively. The supported firmware URL "
+            "schemes are 'file', 'http', 'https' and 'swift'. The "
+            "supported values for firmware component are 'ilo', 'cpld', "
+            "'power_pic', 'bios' and 'chassis'. The firmware images will "
+            "be applied (in the order given) one by one on the baremetal "
+            "server. For more information, see "
+            "https://docs.openstack.org/ironic/latest/admin/drivers/ilo.html#initiating-firmware-update-as-manual-clean-step"  # noqa
+        ),
+        'required': True
+    }
+}
+
+_FIRMWARE_UPDATE_SUM_ARGSINFO = {
+    'url': {
+        'description': (
+            "The image location for SPP (Service Pack for Proliant) ISO."
+        ),
+        'required': True
+    },
+    'checksum': {
+        'description': (
+            "The md5 checksum of the SPP image file."
+        ),
+        'required': True
+    },
+    'components': {
+        'description': (
+            "The list of firmware component filenames. If not specified, "
+            "SUM updates all the firmware components."
+        ),
+        'required': False
+    }
+}
+
+
+def _execute_ilo_step(node, step, *args, **kwargs):
+    """Executes a particular deploy or clean step.
 
     :param node: an Ironic node object.
-    :param step: a clean step to be executed.
-    :param args: The args to be passed to the clean step.
-    :param kwargs: The kwargs to be passed to the clean step.
-    :raises: NodeCleaningFailure, on failure to execute step.
+    :param step: a step to be executed.
+    :param args: The args to be passed to the step.
+    :param kwargs: The kwargs to be passed to the step.
+    :raises: NodeCleaningFailure, on failure to execute the clean step.
+    :raises: InstanceDeployFailure, on failure to execute the deploy step.
     """
     ilo_object = ilo_common.get_ilo_object(node)
 
     try:
-        clean_step = getattr(ilo_object, step)
+        step_method = getattr(ilo_object, step)
     except AttributeError:
-        # The specified clean step is not present in the proliantutils
+        # The specified clean/deploy step is not present in the proliantutils
         # package. Raise exception to update the proliantutils package
         # to newer version.
-        raise exception.NodeCleaningFailure(
-            _("Clean step '%s' not found. 'proliantutils' package needs to be "
-              "updated.") % step)
+        msg = (_("Step '%s' not found. 'proliantutils' package needs to be "
+                 "updated.") % step)
+        if node.clean_step:
+            raise exception.NodeCleaningFailure(msg)
+        raise exception.InstanceDeployFailure(msg)
     try:
-        clean_step(*args, **kwargs)
+        step_method(*args, **kwargs)
     except ilo_error.IloCommandNotSupportedError:
-        # This clean step is not supported on Gen8 and below servers.
-        # Log the failure and continue with cleaning.
-        LOG.warning("'%(step)s' clean step is not supported on node "
-                    "%(uuid)s. Skipping the clean step.",
+        # This step is not supported on Gen8 and below servers.
+        # Log the failure and continue with cleaning or deployment.
+        LOG.warning("'%(step)s' step is not supported on node "
+                    "%(uuid)s. Skipping the step.",
                     {'step': step, 'uuid': node.uuid})
     except ilo_error.IloError as ilo_exception:
-        raise exception.NodeCleaningFailure(_(
-            "Clean step %(step)s failed "
-            "on node %(node)s with error: %(err)s") %
-            {'node': node.uuid, 'step': step, 'err': ilo_exception})
+        msg = (_("Step %(step)s failed on node %(node)s with "
+                 "error: %(err)s") %
+               {'node': node.uuid, 'step': step, 'err': ilo_exception})
+        if node.clean_step:
+            raise exception.NodeCleaningFailure(msg)
+        raise exception.InstanceDeployFailure(msg)
 
 
 def _should_collect_logs(command):
@@ -229,39 +306,54 @@ class IloManagement(base.ManagementInterface):
         return ipmi_management.get_sensors_data(task)
 
     @METRICS.timer('IloManagement.reset_ilo')
+    @base.deploy_step(priority=0)
     @base.clean_step(priority=CONF.ilo.clean_priority_reset_ilo)
     def reset_ilo(self, task):
         """Resets the iLO.
 
         :param task: a task from TaskManager.
-        :raises: NodeCleaningFailure, on failure to execute step.
+        :raises: NodeCleaningFailure, on failure to execute of clean step.
+        :raises: InstanceDeployFailure, on failure to execute of deploy step.
         """
-        return _execute_ilo_clean_step(task.node, 'reset_ilo')
+        node = task.node
+        _execute_ilo_step(node, 'reset_ilo')
+
+        # Reset iLO ejects virtual media
+        # Re-create the environment for agent boot, if required
+        task.driver.boot.clean_up_ramdisk(task)
+        deploy_opts = deploy_utils.build_agent_options(node)
+        task.driver.boot.prepare_ramdisk(task, deploy_opts)
 
     @METRICS.timer('IloManagement.reset_ilo_credential')
+    @base.deploy_step(priority=0, argsinfo=_RESET_ILO_CREDENTIALS_ARGSINFO)
     @base.clean_step(priority=CONF.ilo.clean_priority_reset_ilo_credential)
-    def reset_ilo_credential(self, task):
+    def reset_ilo_credential(self, task, change_password=None):
         """Resets the iLO password.
 
         :param task: a task from TaskManager.
-        :raises: NodeCleaningFailure, on failure to execute step.
+        :param change_password: Value for password to update on iLO.
+        :raises: NodeCleaningFailure, on failure to execute of clean step.
+        :raises: InstanceDeployFailure, on failure to execute of deploy step.
         """
         info = task.node.driver_info
-        password = info.pop('ilo_change_password', None)
+        password = change_password
+        if not password:
+            password = info.pop('ilo_change_password', None)
 
         if not password:
             LOG.info("Missing 'ilo_change_password' parameter in "
-                     "driver_info. Clean step 'reset_ilo_credential' is "
+                     "driver_info. Step 'reset_ilo_credential' is "
                      "not performed on node %s.", task.node.uuid)
             return
 
-        _execute_ilo_clean_step(task.node, 'reset_ilo_credential', password)
+        _execute_ilo_step(task.node, 'reset_ilo_credential', password)
 
         info['ilo_password'] = password
         task.node.driver_info = info
         task.node.save()
 
     @METRICS.timer('IloManagement.reset_bios_to_default')
+    @base.deploy_step(priority=0)
     @base.clean_step(priority=CONF.ilo.clean_priority_reset_bios_to_default)
     def reset_bios_to_default(self, task):
         """Resets the BIOS settings to default values.
@@ -270,11 +362,13 @@ class IloManagement(base.ManagementInterface):
         only on HP Proliant Gen9 and above servers.
 
         :param task: a task from TaskManager.
-        :raises: NodeCleaningFailure, on failure to execute step.
+        :raises: NodeCleaningFailure, on failure to execute of clean step.
+        :raises: InstanceDeployFailure, on failure to execute of deploy step.
         """
-        return _execute_ilo_clean_step(task.node, 'reset_bios_to_default')
+        return _execute_ilo_step(task.node, 'reset_bios_to_default')
 
     @METRICS.timer('IloManagement.reset_secure_boot_keys_to_default')
+    @base.deploy_step(priority=0)
     @base.clean_step(priority=CONF.ilo.
                      clean_priority_reset_secure_boot_keys_to_default)
     def reset_secure_boot_keys_to_default(self, task):
@@ -284,11 +378,13 @@ class IloManagement(base.ManagementInterface):
         operation is supported only on HP Proliant Gen9 and above servers.
 
         :param task: a task from TaskManager.
-        :raises: NodeCleaningFailure, on failure to execute step.
+        :raises: NodeCleaningFailure, on failure to execute of clean step.
+        :raises: InstanceDeployFailure, on failure to execute of deploy step.
         """
-        return _execute_ilo_clean_step(task.node, 'reset_secure_boot_keys')
+        return _execute_ilo_step(task.node, 'reset_secure_boot_keys')
 
     @METRICS.timer('IloManagement.clear_secure_boot_keys')
+    @base.deploy_step(priority=0)
     @base.clean_step(priority=CONF.ilo.clean_priority_clear_secure_boot_keys)
     def clear_secure_boot_keys(self, task):
         """Clear all secure boot keys.
@@ -297,9 +393,10 @@ class IloManagement(base.ManagementInterface):
         on HP Proliant Gen9 and above servers.
 
         :param task: a task from TaskManager.
-        :raises: NodeCleaningFailure, on failure to execute step.
+        :raises: NodeCleaningFailure, on failure to execute of clean step.
+        :raises: InstanceDeployFailure, on failure to execute of deploy step.
         """
-        return _execute_ilo_clean_step(task.node, 'clear_secure_boot_keys')
+        return _execute_ilo_step(task.node, 'clear_secure_boot_keys')
 
     @METRICS.timer('IloManagement.activate_license')
     @base.clean_step(priority=0, abortable=False, argsinfo={
@@ -316,7 +413,7 @@ class IloManagement(base.ManagementInterface):
 
         :param task: a TaskManager object.
         :raises: InvalidParameterValue, if any of the arguments are invalid.
-        :raises: NodeCleaningFailure, on failure to execute clean step.
+        :raises: NodeCleaningFailure, on failure to execute of clean step.
         """
         ilo_license_key = kwargs.get('ilo_license_key')
         node = task.node
@@ -331,36 +428,13 @@ class IloManagement(base.ManagementInterface):
 
         LOG.debug("Activating iLO license for node %(node)s ...",
                   {'node': node.uuid})
-        _execute_ilo_clean_step(node, 'activate_license', ilo_license_key)
+        _execute_ilo_step(node, 'activate_license', ilo_license_key)
         LOG.info("iLO license activated for node %s.", node.uuid)
 
     @METRICS.timer('IloManagement.update_firmware')
-    @base.clean_step(priority=0, abortable=False, argsinfo={
-        'firmware_update_mode': {
-            'description': (
-                "This argument indicates the mode (or mechanism) of firmware "
-                "update procedure. Supported value is 'ilo'."
-            ),
-            'required': True
-        },
-        'firmware_images': {
-            'description': (
-                "This argument represents the ordered list of JSON "
-                "dictionaries of firmware images. Each firmware image "
-                "dictionary consists of three mandatory fields, namely 'url', "
-                "'checksum' and 'component'. These fields represent firmware "
-                "image location URL, md5 checksum of image file and firmware "
-                "component type respectively. The supported firmware URL "
-                "schemes are 'file', 'http', 'https' and 'swift'. The "
-                "supported values for firmware component are 'ilo', 'cpld', "
-                "'power_pic', 'bios' and 'chassis'. The firmware images will "
-                "be applied (in the order given) one by one on the baremetal "
-                "server. For more information, see "
-                "https://docs.openstack.org/ironic/latest/admin/drivers/ilo.html#initiating-firmware-update-as-manual-clean-step"  # noqa
-            ),
-            'required': True
-        }
-    })
+    @base.deploy_step(priority=0, argsinfo=_FIRMWARE_UPDATE_ARGSINFO)
+    @base.clean_step(priority=0, abortable=False,
+                     argsinfo=_FIRMWARE_UPDATE_ARGSINFO)
     @firmware_processor.verify_firmware_update_args
     def update_firmware(self, task, **kwargs):
         """Updates the firmware.
@@ -368,7 +442,8 @@ class IloManagement(base.ManagementInterface):
         :param task: a TaskManager object.
         :raises: InvalidParameterValue if update firmware mode is not 'ilo'.
                  Even applicable for invalid input cases.
-        :raises: NodeCleaningFailure, on failure to execute step.
+        :raises: NodeCleaningFailure, on failure to execute of clean step.
+        :raises: InstanceDeployFailure, on failure to execute of deploy step.
         """
         node = task.node
         fw_location_objs_n_components = []
@@ -406,7 +481,10 @@ class IloManagement(base.ManagementInterface):
                       "on node: %(node)s ... failed",
                       {'firmware_image': firmware_image_info,
                        'node': node.uuid})
-            raise exception.NodeCleaningFailure(node=node.uuid, reason=ilo_exc)
+            if node.clean_step:
+                raise exception.NodeCleaningFailure(node=node.uuid,
+                                                    reason=ilo_exc)
+            raise exception.InstanceDeployFailure(reason=ilo_exc)
 
         # Updating of firmware images happen here.
         try:
@@ -416,13 +494,14 @@ class IloManagement(base.ManagementInterface):
                           "node: %(node)s ... in progress",
                           {'firmware_file': fw_location, 'node': node.uuid})
 
-                _execute_ilo_clean_step(
+                _execute_ilo_step(
                     node, 'update_firmware', fw_location, component)
 
                 LOG.debug("Firmware update for %(firmware_file)s on "
                           "node: %(node)s ... done",
                           {'firmware_file': fw_location, 'node': node.uuid})
-        except exception.NodeCleaningFailure:
+        except (exception.NodeCleaningFailure,
+                exception.InstanceDeployFailure):
             with excutils.save_and_reraise_exception():
                 LOG.error("Firmware update for %(firmware_file)s on "
                           "node: %(node)s failed.",
@@ -431,35 +510,23 @@ class IloManagement(base.ManagementInterface):
             for fw_loc_obj_n_comp_tup in fw_location_objs_n_components:
                 fw_loc_obj_n_comp_tup[0].remove()
 
+        # Firmware might have ejected the virtual media, if it was used.
+        # Re-create the environment for agent boot, if required
+        task.driver.boot.clean_up_ramdisk(task)
+        deploy_opts = deploy_utils.build_agent_options(node)
+        task.driver.boot.prepare_ramdisk(task, deploy_opts)
+
         LOG.info("All Firmware update operations completed successfully "
                  "for node: %s.", node.uuid)
 
     @METRICS.timer('IloManagement.update_firmware_sum')
-    @base.clean_step(priority=0, abortable=False, argsinfo={
-        'url': {
-            'description': (
-                "The image location for SPP (Service Pack for Proliant) ISO."
-            ),
-            'required': True
-        },
-        'checksum': {
-            'description': (
-                "The md5 checksum of the SPP image file."
-            ),
-            'required': True
-        },
-        'components': {
-            'description': (
-                "The list of firmware component filenames. If not specified, "
-                "SUM updates all the firmware components."
-            ),
-            'required': False}
-    })
+    @base.clean_step(priority=0, abortable=False,
+                     argsinfo=_FIRMWARE_UPDATE_SUM_ARGSINFO)
     def update_firmware_sum(self, task, **kwargs):
         """Updates the firmware using Smart Update Manager (SUM).
 
         :param task: a TaskManager object.
-        :raises: NodeCleaningFailure, on failure to execute step.
+        :raises: NodeCleaningFailure, on failure to execute of clean step.
         """
         node = task.node
         # The arguments are validated and sent to the ProliantHardwareManager
@@ -532,6 +599,7 @@ class IloManagement(base.ManagementInterface):
         """
         # Getting target info
         node = task.node
+        macs = [port['address'] for port in task.ports]
         boot_volume = node.driver_internal_info.get('boot_from_volume')
         volume = volume_target.VolumeTarget.get_by_uuid(task.context,
                                                         boot_volume)
@@ -553,7 +621,7 @@ class IloManagement(base.ManagementInterface):
             auth_method = 'CHAP' if username else None
             ilo_object.set_iscsi_info(
                 iqn, lun, host, port, auth_method=auth_method,
-                username=username, password=password)
+                username=username, password=password, macs=macs)
         except ilo_error.IloCommandNotSupportedInBiosError as ilo_exception:
             operation = (_("Setting of target IQN %(target_iqn)s for node "
                            "%(node)s")
@@ -577,7 +645,8 @@ class IloManagement(base.ManagementInterface):
         """
         ilo_object = ilo_common.get_ilo_object(task.node)
         try:
-            ilo_object.unset_iscsi_info()
+            macs = [port['address'] for port in task.ports]
+            ilo_object.unset_iscsi_info(macs=macs)
         except ilo_error.IloCommandNotSupportedInBiosError as ilo_exception:
             operation = (_("Unsetting of iSCSI target for node %(node)s")
                          % {'node': task.node.uuid})
@@ -614,3 +683,163 @@ class IloManagement(base.ManagementInterface):
         except ilo_error.IloError as ilo_exception:
             raise exception.IloOperationError(operation=operation,
                                               error=ilo_exception)
+
+
+class Ilo5Management(IloManagement):
+
+    def _set_driver_internal_value(self, task, value, *keys):
+        driver_internal_info = task.node.driver_internal_info
+        for key in keys:
+            driver_internal_info[key] = value
+        task.node.driver_internal_info = driver_internal_info
+        task.node.save()
+
+    def _pop_driver_internal_values(self, task, *keys):
+        driver_internal_info = task.node.driver_internal_info
+        for key in keys:
+            driver_internal_info.pop(key, None)
+        task.node.driver_internal_info = driver_internal_info
+        task.node.save()
+
+    def _set_clean_failed(self, task, msg):
+        LOG.error("Out-of-band sanitize disk erase job failed for node "
+                  "%(node)s. Message: '%(message)s'.",
+                  {'node': task.node.uuid, 'message': msg})
+        task.node.last_error = msg
+        task.process_event('fail')
+
+    def _wait_for_disk_erase_status(self, node):
+        """Wait for out-of-band sanitize disk erase to be completed."""
+        interval = CONF.ilo.oob_erase_devices_job_status_interval
+        ilo_object = ilo_common.get_ilo_object(node)
+        time_elps = [0]
+
+        # This will loop indefinitely till disk erase is complete
+        def _wait():
+            if ilo_object.has_disk_erase_completed():
+                raise loopingcall.LoopingCallDone()
+
+            time_elps[0] += interval
+            LOG.debug("%(tim)s secs elapsed while waiting for out-of-band "
+                      "sanitize disk erase to complete for node %(node)s.",
+                      {'tim': time_elps[0], 'node': node.uuid})
+
+        # Start a timer and wait for the operation to complete.
+        timer = loopingcall.FixedIntervalLoopingCall(_wait)
+        timer.start(interval=interval).wait()
+        return True
+
+    def _validate_erase_pattern(self, erase_pattern, node):
+        invalid = False
+        if isinstance(erase_pattern, dict):
+            for device_type, pattern in erase_pattern.items():
+                if device_type == 'hdd' and pattern in (
+                        'overwrite', 'crypto', 'zero'):
+                        continue
+                elif device_type == 'ssd' and pattern in (
+                        'block', 'crypto', 'zero'):
+                        continue
+                else:
+                    invalid = True
+                    break
+        else:
+            invalid = True
+
+        if invalid:
+            msg = (_("Erase pattern '%(value)s' is invalid. Clean step "
+                     "'erase_devices' is not executed for %(node)s. Supported "
+                     "patterns are, for "
+                     "'hdd': ('overwrite', 'crypto', 'zero') and for "
+                     "'ssd': ('block', 'crypto', 'zero'). "
+                     "Ex. {'hdd': 'overwrite', 'ssd': 'block'}")
+                   % {'value': erase_pattern, 'node': node.uuid})
+            LOG.error(msg)
+            raise exception.InvalidParameterValue(msg)
+
+    @METRICS.timer('Ilo5Management.erase_devices')
+    @base.clean_step(priority=0, abortable=False, argsinfo={
+        'erase_pattern': {
+            'description': (
+                'Dictionary of disk type and corresponding erase pattern '
+                'to be used to perform specific out-of-band sanitize disk '
+                'erase. Supported values are, '
+                'for "hdd": ("overwrite", "crypto", "zero"), '
+                'for "ssd": ("block", "crypto", "zero"). Default pattern is: '
+                '{"hdd": "overwrite", "ssd": "block"}.'
+            ),
+            'required': False
+        }
+    })
+    def erase_devices(self, task, **kwargs):
+        """Erase all the drives on the node.
+
+        This method performs out-of-band sanitize disk erase on all the
+        supported physical drives in the node. This erase cannot be performed
+        on logical drives.
+
+        :param task: a TaskManager instance.
+        :raises: InvalidParameterValue, if any of the arguments are invalid.
+        :raises: IloError on an error from iLO.
+        """
+        erase_pattern = kwargs.get('erase_pattern',
+                                   {'hdd': 'overwrite', 'ssd': 'block'})
+        node = task.node
+        self._validate_erase_pattern(erase_pattern, node)
+        driver_internal_info = node.driver_internal_info
+        LOG.debug("Calling out-of-band sanitize disk erase for node %(node)s",
+                  {'node': node.uuid})
+        try:
+            ilo_object = ilo_common.get_ilo_object(node)
+            disk_types = ilo_object.get_available_disk_types()
+            LOG.info("Disk type detected are: %(disk_types)s. Sanitize disk "
+                     "erase are now exercised for one after another disk type "
+                     "for node %(node)s.",
+                     {'disk_types': disk_types, 'node': node.uuid})
+
+            if disk_types:
+                # First disk-erase will execute for HDD's and after reboot only
+                # try for SSD, since both share same redfish api and would be
+                # overwritten.
+                if not driver_internal_info.get(
+                        'ilo_disk_erase_hdd_check') and ('HDD' in disk_types):
+                    ilo_object.do_disk_erase('HDD', erase_pattern.get('hdd'))
+                    self._set_driver_internal_value(
+                        task, True, 'cleaning_reboot',
+                        'ilo_disk_erase_hdd_check')
+                    self._set_driver_internal_value(
+                        task, False, 'skip_current_clean_step')
+                    deploy_opts = deploy_utils.build_agent_options(task.node)
+                    task.driver.boot.prepare_ramdisk(task, deploy_opts)
+                    manager_utils.node_power_action(task, states.REBOOT)
+                    return states.CLEANWAIT
+
+                if not driver_internal_info.get(
+                        'ilo_disk_erase_ssd_check') and ('SSD' in disk_types):
+                    ilo_object.do_disk_erase('SSD', erase_pattern.get('ssd'))
+                    self._set_driver_internal_value(
+                        task, True, 'ilo_disk_erase_hdd_check',
+                        'ilo_disk_erase_ssd_check', 'cleaning_reboot')
+                    self._set_driver_internal_value(
+                        task, False, 'skip_current_clean_step')
+                    deploy_opts = deploy_utils.build_agent_options(task.node)
+                    task.driver.boot.prepare_ramdisk(task, deploy_opts)
+                    manager_utils.node_power_action(task, states.REBOOT)
+                    return states.CLEANWAIT
+
+                # It will wait until disk erase will complete
+                if self._wait_for_disk_erase_status(task.node):
+                    LOG.info("For node %(uuid)s erase_devices clean "
+                             "step is done.", {'uuid': task.node.uuid})
+                    self._pop_driver_internal_values(
+                        task, 'ilo_disk_erase_hdd_check',
+                        'ilo_disk_erase_ssd_check')
+            else:
+                LOG.info("No drive found to perform out-of-band sanitize "
+                         "disk erase for node %(node)s", {'node': node.uuid})
+        except ilo_error.IloError as ilo_exception:
+            self._pop_driver_internal_values(task,
+                                             'ilo_disk_erase_hdd_check',
+                                             'ilo_disk_erase_ssd_check',
+                                             'cleaning_reboot',
+                                             'skip_current_clean_step')
+            self._set_clean_failed(task, ilo_exception)
