@@ -17,12 +17,15 @@ from oslo_log import log
 from oslo_utils import importutils
 from oslo_utils import units
 
+from ironic.common import boot_modes
 from ironic.common import exception
 from ironic.common.i18n import _
 from ironic.common import states
+from ironic.common import utils
 from ironic.drivers import base
 from ironic.drivers.modules import inspect_utils
 from ironic.drivers.modules.redfish import utils as redfish_utils
+from ironic.drivers import utils as drivers_utils
 
 LOG = log.getLogger(__name__)
 
@@ -37,6 +40,11 @@ if sushy:
         sushy.PROCESSOR_ARCH_OEM: 'oem'
     }
 
+    BOOT_MODE_MAP = {
+        sushy.BOOT_SOURCE_MODE_UEFI: boot_modes.UEFI,
+        sushy.BOOT_SOURCE_MODE_BIOS: boot_modes.LEGACY_BIOS
+    }
+
 
 class RedfishInspect(base.InspectInterface):
 
@@ -115,6 +123,8 @@ class RedfishInspect(base.InspectInterface):
         simple_storage_size = 0
 
         try:
+            LOG.debug("Attempting to discover system simple storage size for "
+                      "node %(node)s", {'node': task.node.uuid})
             if (system.simple_storage and
                     system.simple_storage.disks_sizes_bytes):
                 simple_storage_size = [
@@ -124,7 +134,7 @@ class RedfishInspect(base.InspectInterface):
 
                 simple_storage_size = simple_storage_size[0]
 
-        except sushy.SushyError as ex:
+        except sushy.exceptions.SushyError as ex:
             LOG.debug("No simple storage information discovered "
                       "for node %(node)s: %(err)s", {'node': task.node.uuid,
                                                      'err': ex})
@@ -132,6 +142,8 @@ class RedfishInspect(base.InspectInterface):
         storage_size = 0
 
         try:
+            LOG.debug("Attempting to discover system storage volume size for "
+                      "node %(node)s", {'node': task.node.uuid})
             if system.storage and system.storage.volumes_sizes_bytes:
                 storage_size = [
                     size for size in system.storage.volumes_sizes_bytes
@@ -140,11 +152,28 @@ class RedfishInspect(base.InspectInterface):
 
                 storage_size = storage_size[0]
 
-        except sushy.SushyError as ex:
+        except sushy.exceptions.SushyError as ex:
             LOG.debug("No storage volume information discovered "
                       "for node %(node)s: %(err)s", {'node': task.node.uuid,
                                                      'err': ex})
 
+        try:
+            if not storage_size:
+                LOG.debug("Attempting to discover system storage drive size "
+                          "for node %(node)s", {'node': task.node.uuid})
+                if system.storage and system.storage.drives_sizes_bytes:
+                    storage_size = [
+                        size for size in system.storage.drives_sizes_bytes
+                        if size >= 4 * units.Gi
+                    ] or [0]
+
+                    storage_size = storage_size[0]
+
+        except sushy.exceptions.SushyError as ex:
+            LOG.debug("No storage drive information discovered "
+                      "for node %(node)s: %(err)s", {'node': task.node.uuid,
+                                                     'err': ex})
+
         # NOTE(etingof): pick the smallest disk larger than 4G among available
         if simple_storage_size and storage_size:
             local_gb = min(simple_storage_size, storage_size)
@@ -161,10 +190,19 @@ class RedfishInspect(base.InspectInterface):
 
         if local_gb:
             inspected_properties['local_gb'] = str(local_gb)
-
         else:
             LOG.warning("Could not provide a valid storage size configured "
-                        "for node %(node)s", {'node': task.node.uuid})
+                        "for node %(node)s. Assuming this is a disk-less node",
+                        {'node': task.node.uuid})
+            inspected_properties['local_gb'] = '0'
+
+        if system.boot.mode:
+            if not drivers_utils.get_node_capability(task.node, 'boot_mode'):
+                capabilities = utils.get_updated_capabilities(
+                    inspected_properties.get('capabilities', ''),
+                    {'boot_mode': BOOT_MODE_MAP[system.boot.mode]})
+
+                inspected_properties['capabilities'] = capabilities
 
         valid_keys = self.ESSENTIAL_PROPERTIES
         missing_keys = valid_keys - set(inspected_properties)
@@ -183,12 +221,21 @@ class RedfishInspect(base.InspectInterface):
                                      'node': task.node.uuid})
 
         if (system.ethernet_interfaces and
-                system.ethernet_interfaces.eth_summary):
-            macs = system.ethernet_interfaces.eth_summary
-
-            # Create ports for the nics detected.
-            inspect_utils.create_ports_if_not_exist(task, macs)
+                system.ethernet_interfaces.summary):
+            macs = system.ethernet_interfaces.summary
 
+            # Create ports for the discovered NICs being in 'enabled' state
+            enabled_macs = {nic_mac: nic_state
+                            for nic_mac, nic_state in macs.items()
+                            if nic_state == sushy.STATE_ENABLED}
+            if enabled_macs:
+                inspect_utils.create_ports_if_not_exist(
+                    task, enabled_macs, get_mac_address=lambda x: x[0])
+            else:
+                LOG.warning("Not attempting to create any port as no NICs "
+                            "were discovered in 'enabled' state for node "
+                            "%(node)s: %(mac_data)s",
+                            {'mac_data': macs, 'node': task.node.uuid})
         else:
             LOG.warning("No NIC information discovered "
                         "for node %(node)s", {'node': task.node.uuid})
