@@ -27,9 +27,8 @@ import testtools
 
 from ironic.common import context
 from ironic.common import exception
-from ironic.common.glance_service import base_image_service
+from ironic.common.glance_service import image_service
 from ironic.common.glance_service import service_utils
-from ironic.common.glance_service.v2 import image_service as glance_v2
 from ironic.common import image_service as service
 from ironic.tests import base
 from ironic.tests.unit import stubs
@@ -95,9 +94,6 @@ class TestGlanceImageService(base.TestCase):
         self.context.project_id = 'fake'
         self.service = service.GlanceImageService(self.client, self.context)
 
-        self.config(glance_api_servers=['http://localhost'], group='glance')
-        self.config(auth_strategy='keystone', group='glance')
-
     @staticmethod
     def _make_fixture(**kwargs):
         fixture = {'name': None,
@@ -201,13 +197,13 @@ class TestGlanceImageService(base.TestCase):
         writer = NullWriter()
 
         # When retries are disabled, we should get an exception
-        self.config(glance_num_retries=0, group='glance')
+        self.config(num_retries=0, group='glance')
         self.assertRaises(exception.GlanceConnectionFailed,
                           stub_service.download, image_id, writer)
 
         # Now lets enable retries. No exception should happen now.
         tries = [0]
-        self.config(glance_num_retries=1, group='glance')
+        self.config(num_retries=1, group='glance')
         stub_service.download(image_id, writer)
         self.assertTrue(mock_sleep.called)
 
@@ -248,9 +244,9 @@ class TestGlanceImageService(base.TestCase):
 
         self.config(allowed_direct_url_schemes=['file'], group='glance')
 
-        # patching open in base_image_service module namespace
+        # patching open in image_service module namespace
         # to make call-spec assertions
-        with mock.patch('ironic.common.glance_service.base_image_service.open',
+        with mock.patch('ironic.common.glance_service.image_service.open',
                         new=mock.mock_open(), create=True) as mock_ironic_open:
             with open('/whatever/target', 'w') as mock_target_fd:
                 stub_service.download(image_id, mock_target_fd)
@@ -358,9 +354,8 @@ class CheckImageServiceTestCase(base.TestCase):
                     service_type='image',
                     region_name='SomeRegion',
                     interface='internal',
-                    auth_strategy='keystone',
                     group='glance')
-        base_image_service._GLANCE_SESSION = None
+        image_service._GLANCE_SESSION = None
 
     def test_check_image_service_client_already_set(self, mock_gclient,
                                                     mock_sess, mock_adapter,
@@ -370,7 +365,7 @@ class CheckImageServiceTestCase(base.TestCase):
 
         self.service.client = True
 
-        wrapped_func = base_image_service.check_image_service(func)
+        wrapped_func = image_service.check_image_service(func)
         self.assertTrue(wrapped_func(self.service))
         self.assertEqual(0, mock_gclient.call_count)
         self.assertEqual(0, mock_sess.call_count)
@@ -397,7 +392,7 @@ class CheckImageServiceTestCase(base.TestCase):
         uuid = uuidutils.generate_uuid()
         params = {'image_href': uuid}
 
-        wrapped_func = base_image_service.check_image_service(func)
+        wrapped_func = image_service.check_image_service(func)
         self.assertEqual(((), params), wrapped_func(self.service, **params))
         self._assert_client_call(mock_gclient, 'glance_url')
         mock_auth.assert_called_once_with('glance')
@@ -421,7 +416,7 @@ class CheckImageServiceTestCase(base.TestCase):
         uuid = uuidutils.generate_uuid()
         params = {'image_href': uuid}
 
-        wrapped_func = base_image_service.check_image_service(func)
+        wrapped_func = image_service.check_image_service(func)
         self.assertEqual(((), params), wrapped_func(self.service, **params))
         self._assert_client_call(mock_gclient, 'glance_url', user=True)
         mock_sess.assert_called_once_with('glance')
@@ -432,51 +427,22 @@ class CheckImageServiceTestCase(base.TestCase):
                                            mock.sentinel.auth)
         mock_auth.assert_called_once_with('glance')
 
-    def test_check_image_service__deprecated_opts(self, mock_gclient,
-                                                  mock_sess, mock_adapter,
-                                                  mock_sauth, mock_auth):
-        def func(service, *args, **kwargs):
-            return args, kwargs
-
-        mock_adapter.return_value = adapter = mock.Mock()
-        adapter.get_endpoint.return_value = 'glance_url'
-        uuid = uuidutils.generate_uuid()
-        params = {'image_href': uuid}
-        self.config(glance_api_servers='https://localhost:1234',
-                    glance_api_insecure=True,
-                    glance_cafile='cafile',
-                    region_name=None,
-                    group='glance')
-
-        wrapped_func = base_image_service.check_image_service(func)
-        self.assertEqual(((), params), wrapped_func(self.service, **params))
-        self.assertEqual('https://localhost:1234',
-                         base_image_service.CONF.glance.endpoint_override)
-        self._assert_client_call(mock_gclient, 'glance_url')
-        mock_sess.assert_called_once_with('glance', insecure=True,
-                                          cacert='cafile')
-        mock_adapter.assert_called_once_with(
-            'glance', session=mock.sentinel.session,
-            auth=mock.sentinel.auth)
-        self.assertEqual(0, mock_sauth.call_count)
-        mock_auth.assert_called_once_with('glance')
-
     def test_check_image_service__no_auth(self, mock_gclient, mock_sess,
                                           mock_adapter, mock_sauth, mock_auth):
         def func(service, *args, **kwargs):
             return args, kwargs
 
         self.config(endpoint_override='foo',
-                    auth_strategy='noauth',
+                    auth_type='none',
                     group='glance')
         mock_adapter.return_value = adapter = mock.Mock()
         adapter.get_endpoint.return_value = 'foo'
         uuid = uuidutils.generate_uuid()
         params = {'image_href': uuid}
 
-        wrapped_func = base_image_service.check_image_service(func)
+        wrapped_func = image_service.check_image_service(func)
         self.assertEqual(((), params), wrapped_func(self.service, **params))
-        self.assertEqual('none', base_image_service.CONF.glance.auth_type)
+        self.assertEqual('none', image_service.CONF.glance.auth_type)
         self._assert_client_call(mock_gclient, 'foo')
         mock_sess.assert_called_once_with('glance')
         mock_adapter.assert_called_once_with('glance',
@@ -818,8 +784,8 @@ class TestSwiftTempUrlCache(base.TestCase):
             {'uuid': fake_image['id'], 'exp_time': exp_time}
         )
         self.glance_service._cache[fake_image['id']] = (
-            glance_v2.TempUrlCacheElement(url=temp_url,
-                                          url_expires_at=exp_time)
+            image_service.TempUrlCacheElement(url=temp_url,
+                                              url_expires_at=exp_time)
         )
 
         cleanup_mock = mock.Mock()
@@ -846,7 +812,7 @@ class TestSwiftTempUrlCache(base.TestCase):
         )
         query = '?temp_url_sig=hmacsig&temp_url_expires=%s'
         self.glance_service._cache[fake_image['id']] = (
-            glance_v2.TempUrlCacheElement(
+            image_service.TempUrlCacheElement(
                 url=(CONF.glance.swift_endpoint_url + path
                      + query % old_exp_time),
                 url_expires_at=old_exp_time)
@@ -875,21 +841,21 @@ class TestSwiftTempUrlCache(base.TestCase):
 
     def test_remove_expired_items_from_cache(self):
         expired_items = {
-            uuidutils.generate_uuid(): glance_v2.TempUrlCacheElement(
+            uuidutils.generate_uuid(): image_service.TempUrlCacheElement(
                 'fake-url-1',
                 int(time.time()) - 10
             ),
-            uuidutils.generate_uuid(): glance_v2.TempUrlCacheElement(
+            uuidutils.generate_uuid(): image_service.TempUrlCacheElement(
                 'fake-url-2',
                 int(time.time()) + 90  # Agent won't be able to start in time
             )
         }
         valid_items = {
-            uuidutils.generate_uuid(): glance_v2.TempUrlCacheElement(
+            uuidutils.generate_uuid(): image_service.TempUrlCacheElement(
                 'fake-url-3',
                 int(time.time()) + 1000
             ),
-            uuidutils.generate_uuid(): glance_v2.TempUrlCacheElement(
+            uuidutils.generate_uuid(): image_service.TempUrlCacheElement(
                 'fake-url-4',
                 int(time.time()) + 2000
             )
@@ -978,20 +944,6 @@ class TestServiceUtils(base.TestCase):
                           service_utils.parse_image_id,
                           u'http://spam.ham/eggs')
 
-    def test_get_glance_api_server_fail(self):
-        self.assertRaises(exception.InvalidImageRef,
-                          service_utils.get_glance_api_server,
-                          u'http://spam.ham/eggs')
-
-    # TODO(pas-ha) remove in Rocky
-    def test_get_glance_api_server(self):
-        self.config(glance_api_servers='http://spam:1234, https://ham',
-                    group='glance')
-        api_servers = {service_utils.get_glance_api_server(
-            uuidutils.generate_uuid()) for i in range(2)}
-        self.assertEqual({'http://spam:1234', 'https://ham'},
-                         api_servers)
-
     def test_is_glance_image(self):
         image_href = u'uui\u0111'
         self.assertFalse(service_utils.is_glance_image(image_href))
