@@ -10,13 +10,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import copy
 import time
 
 from keystoneauth1 import loading as kaloading
 import mock
 from neutronclient.common import exceptions as neutron_client_exc
 from neutronclient.v2_0 import client
-from oslo_config import cfg
 from oslo_utils import uuidutils
 
 from ironic.common import context
@@ -125,30 +125,10 @@ class TestNeutronClient(base.TestCase):
                                              auth=mock.sentinel.auth)
         self.assertEqual(0, mock_sauth.call_count)
 
-    def test_get_neutron_client_with_deprecated_opts(self, mock_client_init,
-                                                     mock_session,
-                                                     mock_adapter, mock_auth,
-                                                     mock_sauth):
-        self.config(url='neutron_url',
-                    url_timeout=10,
-                    timeout=None,
-                    service_type=None,
-                    group='neutron')
-        mock_adapter.return_value = adapter = mock.Mock()
-        adapter.get_endpoint.return_value = 'neutron_url'
-        self._call_and_assert_client(mock_client_init, 'neutron_url')
-        mock_session.assert_called_once_with('neutron', timeout=10)
-        mock_adapter.assert_called_once_with('neutron',
-                                             session=mock.sentinel.session,
-                                             auth=mock.sentinel.auth,
-                                             endpoint_override='neutron_url')
-
     def test_get_neutron_client_noauth(self, mock_client_init, mock_session,
                                        mock_adapter, mock_auth, mock_sauth):
-        self.config(auth_strategy='noauth',
-                    endpoint_override='neutron_url',
-                    url_timeout=None,
-                    auth_type=None,
+        self.config(endpoint_override='neutron_url',
+                    auth_type='none',
                     timeout=10,
                     group='neutron')
         mock_adapter.return_value = adapter = mock.Mock()
@@ -164,11 +144,6 @@ class TestNeutronClient(base.TestCase):
         mock_auth.assert_called_once_with('neutron')
         self.assertEqual(0, mock_sauth.call_count)
 
-    def test_out_range_auth_strategy(self, mock_client_init, mock_session,
-                                     mock_adapter, mock_auth, mock_eauth):
-        self.assertRaises(ValueError, cfg.CONF.set_override,
-                          'auth_strategy', 'fake', 'neutron')
-
 
 class TestNeutronNetworkActions(db_base.DbTestCase):
 
@@ -197,16 +172,19 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
         self.addCleanup(patcher.stop)
 
     def _test_add_ports_to_network(self, is_client_id,
-                                   security_groups=None):
+                                   security_groups=None,
+                                   add_all_ports=False):
         # Ports will be created only if pxe_enabled is True
         self.node.network_interface = 'neutron'
         self.node.save()
-        object_utils.create_test_port(
+        port2 = object_utils.create_test_port(
             self.context, node_id=self.node.id,
             uuid=uuidutils.generate_uuid(),
-            address='52:54:00:cf:2d:22',
+            address='54:00:00:cf:2d:22',
             pxe_enabled=False
         )
+        if add_all_ports:
+            self.config(add_all_ports=True, group="neutron")
         port = self.ports[0]
         if is_client_id:
             extra = port.extra
@@ -233,21 +211,46 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
         if is_client_id:
             expected_body['port']['extra_dhcp_opts'] = (
                 [{'opt_name': '61', 'opt_value': self._CLIENT_ID}])
-        # Ensure we can create ports
-        self.client_mock.create_port.return_value = {
-            'port': self.neutron_port}
-        expected = {port.uuid: self.neutron_port['id']}
+
+        if add_all_ports:
+            expected_body2 = copy.deepcopy(expected_body)
+            expected_body2['port']['mac_address'] = port2.address
+            expected_body2['fixed_ips'] = []
+            neutron_port2 = {'id': '132f871f-eaec-4fed-9475-0d54465e0f01',
+                             'mac_address': port2.address}
+            self.client_mock.create_port.side_effect = [
+                {'port': self.neutron_port},
+                {'port': neutron_port2}
+            ]
+            expected = {port.uuid: self.neutron_port['id'],
+                        port2.uuid: neutron_port2['id']}
+
+        else:
+            self.client_mock.create_port.return_value = {
+                'port': self.neutron_port}
+            expected = {port.uuid: self.neutron_port['id']}
+
         with task_manager.acquire(self.context, self.node.uuid) as task:
             ports = neutron.add_ports_to_network(
                 task, self.network_uuid, security_groups=security_groups)
             self.assertEqual(expected, ports)
-            self.client_mock.create_port.assert_called_once_with(
-                expected_body)
+            if add_all_ports:
+                calls = [mock.call(expected_body),
+                         mock.call(expected_body2)]
+                self.client_mock.create_port.assert_has_calls(calls)
+            else:
+                self.client_mock.create_port.assert_called_once_with(
+                    expected_body)
 
     def test_add_ports_to_network(self):
         self._test_add_ports_to_network(is_client_id=False,
                                         security_groups=None)
 
+    def test_add_ports_to_network_all_ports(self):
+        self._test_add_ports_to_network(is_client_id=False,
+                                        security_groups=None,
+                                        add_all_ports=True)
+
     @mock.patch.object(neutron, '_verify_security_groups', autospec=True)
     def test_add_ports_to_network_with_sg(self, verify_mock):
         sg_ids = []
@@ -270,23 +273,23 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
 
         self.assertIsNone(
             neutron._verify_security_groups(sg_ids, client))
-        client.list_security_groups.assert_called_once_with()
+        client.list_security_groups.assert_called_once_with(
+            fields='id', id=sg_ids)
 
     def test_verify_sec_groups_less_than_configured(self):
         sg_ids = []
         for i in range(2):
             sg_ids.append(uuidutils.generate_uuid())
 
-        expected_vals = {'security_groups': []}
-        for sg in sg_ids:
-            expected_vals['security_groups'].append({'id': sg})
+        expected_vals = {'security_groups': [{'id': sg_ids[0]}]}
 
         client = mock.MagicMock()
         client.list_security_groups.return_value = expected_vals
 
         self.assertIsNone(
             neutron._verify_security_groups(sg_ids[:1], client))
-        client.list_security_groups.assert_called_once_with()
+        client.list_security_groups.assert_called_once_with(
+            fields='id', id=sg_ids[:1])
 
     def test_verify_sec_groups_more_than_configured(self):
         sg_ids = []
@@ -300,7 +303,8 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
         self.assertRaises(
             exception.NetworkError,
             neutron._verify_security_groups, sg_ids, client)
-        client.list_security_groups.assert_called_once_with()
+        client.list_security_groups.assert_called_once_with(
+            fields='id', id=sg_ids)
 
     def test_verify_sec_groups_no_sg_from_neutron(self):
         sg_ids = []
@@ -313,7 +317,8 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
         self.assertRaises(
             exception.NetworkError,
             neutron._verify_security_groups, sg_ids, client)
-        client.list_security_groups.assert_called_once_with()
+        client.list_security_groups.assert_called_once_with(
+            fields='id', id=sg_ids)
 
     def test_verify_sec_groups_exception_by_neutronclient(self):
         sg_ids = []
@@ -328,7 +333,8 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
             exception.NetworkError,
             "Could not retrieve security groups",
             neutron._verify_security_groups, sg_ids, client)
-        client.list_security_groups.assert_called_once_with()
+        client.list_security_groups.assert_called_once_with(
+            fields='id', id=sg_ids)
 
     def test_add_ports_with_client_id_to_network(self):
         self._test_add_ports_to_network(is_client_id=True)
@@ -439,6 +445,25 @@ class TestNeutronNetworkActions(db_base.DbTestCase):
                  'mac_address': [self.ports[0].address]}
             )
 
+    @mock.patch.object(neutron, 'remove_neutron_ports', autospec=True)
+    def test_remove_ports_from_network_not_all_pxe_enabled_all_ports(
+            self, remove_mock):
+        self.config(add_all_ports=True, group="neutron")
+        object_utils.create_test_port(
+            self.context, node_id=self.node.id,
+            uuid=uuidutils.generate_uuid(),
+            address='52:54:55:cf:2d:32',
+            pxe_enabled=False
+        )
+        with task_manager.acquire(self.context, self.node.uuid) as task:
+            neutron.remove_ports_from_network(task, self.network_uuid)
+            calls = [
+                mock.call(task, {'network_id': self.network_uuid,
+                                 'mac_address': [task.ports[0].address,
+                                                 task.ports[1].address]}),
+            ]
+            remove_mock.assert_has_calls(calls)
+
     def test_remove_neutron_ports(self):
         with task_manager.acquire(self.context, self.node.uuid) as task:
             self.client_mock.list_ports.return_value = {
