@@ -22,7 +22,6 @@ from ironic.conductor import rpcapi
 from ironic.db.sqlalchemy import models
 from ironic.objects import base as obj_base
 from ironic.tests import base
-from ironic import version
 
 
 def _check_versions_compatibility(conf_version, actual_version):
@@ -70,13 +69,6 @@ class ReleaseMappingsTestCase(base.TestCase):
             objects = set(mapping['objects'])
             self.assertTrue(objects.issubset(registered_objects))
 
-    def test_contains_current_release_entry(self):
-        version_info = str(version.version_info)
-        # NOTE(sborkows): We only need first two values from version (like 5.1)
-        # and assume version_info is of the form 'x.y.z'.
-        current_release = version_info[:version_info.rfind('.')]
-        self.assertIn(current_release, release_mappings.RELEASE_MAPPING)
-
     def test_current_rpc_version(self):
         self.assertEqual(rpcapi.ConductorAPI.RPC_API_VERSION,
                          release_mappings.RELEASE_MAPPING['master']['rpc'])
@@ -86,13 +78,14 @@ class ReleaseMappingsTestCase(base.TestCase):
         obj_versions = release_mappings.get_object_versions(
             releases=['master'])
         for obj, vers in obj_versions.items():
-            self.assertEqual(registered_objects[obj][0].VERSION, vers.pop())
+            # vers is a set of versions, not ordered
+            self.assertIn(registered_objects[obj][0].VERSION, vers)
 
     def test_contains_all_db_objects(self):
         self.assertIn('master', release_mappings.RELEASE_MAPPING)
         model_names = set((s.__name__ for s in models.Base.__subclasses__()))
         exceptions = set(['NodeTag', 'ConductorHardwareInterfaces',
-                          'NodeTrait'])
+                          'NodeTrait', 'BIOSSetting', 'DeployTemplateStep'])
         # NOTE(xek): As a rule, all models which can be changed between
         # releases or are sent through RPC should have their counterpart
         # versioned objects.
