@@ -18,6 +18,7 @@ import uuid
 import eventlet
 import futurist
 from futurist import periodics
+from ironic_lib import mdns
 import mock
 from oslo_config import cfg
 from oslo_db import exception as db_exception
@@ -30,9 +31,9 @@ from ironic.conductor import base_manager
 from ironic.conductor import manager
 from ironic.conductor import notification_utils
 from ironic.conductor import task_manager
-from ironic.db import api as dbapi
 from ironic.drivers import fake_hardware
 from ironic.drivers import generic
+from ironic.drivers.modules import deploy_utils
 from ironic.drivers.modules import fake
 from ironic import objects
 from ironic.objects import fields
@@ -218,7 +219,6 @@ class StartStopTestCase(mgr_utils.ServiceSetUpMixin, db_base.DbTestCase):
             (states.ADOPTING, states.ADOPTFAIL),
             (states.RESCUING, states.RESCUEFAIL),
             (states.UNRESCUING, states.UNRESCUEFAIL),
-            (states.DELETING, states.ERROR),
         ]
         nodes = [obj_utils.create_test_node(self.context, uuid=uuid.uuid4(),
                                             driver='fake-hardware',
@@ -249,14 +249,39 @@ class StartStopTestCase(mgr_utils.ServiceSetUpMixin, db_base.DbTestCase):
         self.service.del_host()
         self.assertTrue(self.service._shutdown)
 
-    @mock.patch.object(dbapi, 'get_instance', autospec=True)
-    def test_start_dbapi_single_call(self, mock_dbapi):
+    @mock.patch.object(deploy_utils, 'get_ironic_api_url', autospec=True)
+    @mock.patch.object(mdns, 'Zeroconf', autospec=True)
+    def test_start_with_mdns(self, mock_zc, mock_api_url):
+        CONF.set_override('debug', False)
+        CONF.set_override('enable_mdns', True, 'conductor')
         self._start_service()
-        # NOTE(TheJulia): This seems like it should only be 1, but
-        # the hash ring initailization pulls it's own database connection
-        # instance, which is likely a good thing, thus this is 2 instead of
-        # 3 without reuse of the database connection.
-        self.assertEqual(2, mock_dbapi.call_count)
+        res = objects.Conductor.get_by_hostname(self.context, self.hostname)
+        self.assertEqual(self.hostname, res['hostname'])
+        mock_zc.return_value.register_service.assert_called_once_with(
+            'baremetal',
+            mock_api_url.return_value,
+            params={})
+
+    @mock.patch.object(deploy_utils, 'get_ironic_api_url', autospec=True)
+    @mock.patch.object(mdns, 'Zeroconf', autospec=True)
+    def test_start_with_mdns_and_debug(self, mock_zc, mock_api_url):
+        CONF.set_override('debug', True)
+        CONF.set_override('enable_mdns', True, 'conductor')
+        self._start_service()
+        res = objects.Conductor.get_by_hostname(self.context, self.hostname)
+        self.assertEqual(self.hostname, res['hostname'])
+        mock_zc.return_value.register_service.assert_called_once_with(
+            'baremetal',
+            mock_api_url.return_value,
+            params={'ipa_debug': True})
+
+    def test_del_host_with_mdns(self):
+        mock_zc = mock.Mock(spec=mdns.Zeroconf)
+        self.service._zeroconf = mock_zc
+        self._start_service()
+        self.service.del_host()
+        mock_zc.close.assert_called_once_with()
+        self.assertIsNone(self.service._zeroconf)
 
 
 class CheckInterfacesTestCase(mgr_utils.ServiceSetUpMixin, db_base.DbTestCase):
