@@ -21,6 +21,7 @@ from ironic.common import boot_modes
 from ironic.common import exception
 from ironic.common import network
 from ironic.common import neutron
+from ironic.common import nova
 from ironic.common import states
 from ironic.conductor import rpcapi
 from ironic.conductor import task_manager
@@ -176,7 +177,9 @@ class NodePowerActionTestCase(db_base.DbTestCase):
 
     @mock.patch('ironic.objects.node.NodeSetPowerStateNotification')
     @mock.patch.object(fake.FakePower, 'get_power_state', autospec=True)
-    def test_node_power_action_power_on_notify(self, get_power_mock,
+    @mock.patch.object(nova, 'power_update', autospec=True)
+    def test_node_power_action_power_on_notify(self, mock_power_update,
+                                               get_power_mock,
                                                mock_notif):
         """Test node_power_action to power on node and send notification."""
         self.config(notification_level='info')
@@ -186,6 +189,7 @@ class NodePowerActionTestCase(db_base.DbTestCase):
         node = obj_utils.create_test_node(self.context,
                                           uuid=uuidutils.generate_uuid(),
                                           driver='fake-hardware',
+                                          instance_uuid=uuidutils.uuid,
                                           power_state=states.POWER_OFF)
         task = task_manager.TaskManager(self.context, node.uuid)
 
@@ -214,6 +218,8 @@ class NodePowerActionTestCase(db_base.DbTestCase):
                                      'ironic-conductor', CONF.host,
                                      'baremetal.node.power_set.end',
                                      obj_fields.NotificationLevel.INFO)
+        mock_power_update.assert_called_once_with(
+            task.context, node.instance_uuid, states.POWER_ON)
 
     @mock.patch.object(fake.FakePower, 'get_power_state', autospec=True)
     def test_node_power_action_power_off(self, get_power_mock):
@@ -909,6 +915,11 @@ class DeployingErrorHandlerTestCase(tests_base.TestCase):
                           self.task)
 
     def test_deploying_error_handler(self):
+        info = self.node.driver_internal_info
+        info['deploy_step_index'] = 2
+        info['deployment_reboot'] = True
+        info['deployment_polling'] = True
+        info['skip_current_deploy_step'] = True
         conductor_utils.deploying_error_handler(self.task, self.logmsg,
                                                 self.errmsg)
 
@@ -918,6 +929,9 @@ class DeployingErrorHandlerTestCase(tests_base.TestCase):
         self.assertEqual({}, self.node.deploy_step)
         self.assertNotIn('deploy_step_index', self.node.driver_internal_info)
         self.assertNotIn('deployment_reboot', self.node.driver_internal_info)
+        self.assertNotIn('deployment_polling', self.node.driver_internal_info)
+        self.assertNotIn('skip_current_deploy_step',
+                         self.node.driver_internal_info)
         self.task.process_event.assert_called_once_with('fail')
 
     def _test_deploying_error_handler_cleanup(self, exc, expected_str):
@@ -980,9 +994,9 @@ class ErrorHandlersTestCase(tests_base.TestCase):
         # strict typing of the node power state fields and would fail if passed
         # a Mock object in constructors. A task context is also required for
         # notifications.
-        power_attrs = {'power_state': states.POWER_OFF,
-                       'target_power_state': states.POWER_ON}
-        self.node.configure_mock(**power_attrs)
+        self.node.configure_mock(power_state=states.POWER_OFF,
+                                 target_power_state=states.POWER_ON,
+                                 maintenance=False, maintenance_reason=None)
         self.task.context = self.context
 
     @mock.patch.object(conductor_utils, 'LOG')
@@ -1043,12 +1057,18 @@ class ErrorHandlersTestCase(tests_base.TestCase):
         self.node.clean_step = {'key': 'val'}
         self.node.driver_internal_info = {
             'cleaning_reboot': True,
+            'cleaning_polling': True,
+            'skip_current_clean_step': True,
             'clean_step_index': 0}
         msg = 'error bar'
         conductor_utils.cleaning_error_handler(self.task, msg)
         self.node.save.assert_called_once_with()
         self.assertEqual({}, self.node.clean_step)
         self.assertNotIn('clean_step_index', self.node.driver_internal_info)
+        self.assertNotIn('cleaning_reboot', self.node.driver_internal_info)
+        self.assertNotIn('cleaning_polling', self.node.driver_internal_info)
+        self.assertNotIn('skip_current_clean_step',
+                         self.node.driver_internal_info)
         self.assertEqual(msg, self.node.last_error)
         self.assertTrue(self.node.maintenance)
         self.assertEqual(msg, self.node.maintenance_reason)
@@ -1110,7 +1130,6 @@ class ErrorHandlersTestCase(tests_base.TestCase):
         self.assertEqual('clean failure', self.node.fault)
 
     def test_abort_on_conductor_take_over_cleaning(self):
-        self.node.maintenance = False
         self.node.provision_state = states.CLEANFAIL
         conductor_utils.abort_on_conductor_take_over(self.task)
         self.assertTrue(self.node.maintenance)
@@ -1122,7 +1141,6 @@ class ErrorHandlersTestCase(tests_base.TestCase):
         self.node.save.assert_called_once_with()
 
     def test_abort_on_conductor_take_over_deploying(self):
-        self.node.maintenance = False
         self.node.provision_state = states.DEPLOYFAIL
         conductor_utils.abort_on_conductor_take_over(self.task)
         self.assertFalse(self.node.maintenance)
