@@ -68,7 +68,7 @@ class IloInspectTestCase(test_common.BaseIloTest):
         properties = {'memory_mb': '512', 'local_gb': '10',
                       'cpus': '1', 'cpu_arch': 'x86_64'}
         macs = {'Port 1': 'aa:aa:aa:aa:aa:aa', 'Port 2': 'bb:bb:bb:bb:bb:bb'}
-        capabilities = ''
+        capabilities = {}
         result = {'properties': properties, 'macs': macs}
         get_essential_mock.return_value = result
         get_capabilities_mock.return_value = capabilities
@@ -106,7 +106,7 @@ class IloInspectTestCase(test_common.BaseIloTest):
         properties = {'memory_mb': '512', 'local_gb': 0,
                       'cpus': '1', 'cpu_arch': 'x86_64'}
         macs = {'Port 1': 'aa:aa:aa:aa:aa:aa', 'Port 2': 'bb:bb:bb:bb:bb:bb'}
-        capabilities = ''
+        capabilities = {}
         result = {'properties': properties, 'macs': macs}
         get_essential_mock.return_value = result
         get_capabilities_mock.return_value = capabilities
@@ -129,6 +129,90 @@ class IloInspectTestCase(test_common.BaseIloTest):
                                                           ilo_object_mock)
             create_port_mock.assert_called_once_with(task, macs)
 
+    @mock.patch.object(ilo_inspect.LOG, 'warning',
+                       spec_set=True, autospec=True)
+    @mock.patch.object(ilo_inspect, '_get_capabilities', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(inspect_utils, 'create_ports_if_not_exist',
+                       spec_set=True, autospec=True)
+    @mock.patch.object(ilo_inspect, '_get_essential_properties', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(ilo_power.IloPower, 'get_power_state', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(ilo_common, 'get_ilo_object', spec_set=True,
+                       autospec=True)
+    def test_inspect_ok_gen8(self, get_ilo_object_mock,
+                             power_mock,
+                             get_essential_mock,
+                             create_port_mock,
+                             get_capabilities_mock,
+                             log_mock):
+        ilo_object_mock = get_ilo_object_mock.return_value
+        properties = {'memory_mb': '512', 'local_gb': 10,
+                      'cpus': '1', 'cpu_arch': 'x86_64'}
+        macs = {'Port 1': 'aa:aa:aa:aa:aa:aa', 'Port 2': 'bb:bb:bb:bb:bb:bb'}
+        capabilities = {'server_model': 'Gen8'}
+        result = {'properties': properties, 'macs': macs}
+        get_essential_mock.return_value = result
+        get_capabilities_mock.return_value = capabilities
+        power_mock.return_value = states.POWER_ON
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            expected_properties = {'memory_mb': '512', 'local_gb': 10,
+                                   'cpus': '1', 'cpu_arch': 'x86_64',
+                                   'capabilities': 'server_model:Gen8'}
+            task.driver.inspect.inspect_hardware(task)
+            self.assertEqual(expected_properties, task.node.properties)
+            power_mock.assert_called_once_with(mock.ANY, task)
+            get_essential_mock.assert_called_once_with(task.node,
+                                                       ilo_object_mock)
+            self.assertTrue(log_mock.called)
+            get_capabilities_mock.assert_called_once_with(task.node,
+                                                          ilo_object_mock)
+            create_port_mock.assert_called_once_with(task, macs)
+
+    @mock.patch.object(ilo_inspect.LOG, 'warning',
+                       spec_set=True, autospec=True)
+    @mock.patch.object(ilo_inspect, '_get_capabilities', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(inspect_utils, 'create_ports_if_not_exist',
+                       spec_set=True, autospec=True)
+    @mock.patch.object(ilo_inspect, '_get_essential_properties', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(ilo_power.IloPower, 'get_power_state', spec_set=True,
+                       autospec=True)
+    @mock.patch.object(ilo_common, 'get_ilo_object', spec_set=True,
+                       autospec=True)
+    def test_inspect_ok_gen10(self, get_ilo_object_mock,
+                              power_mock,
+                              get_essential_mock,
+                              create_port_mock,
+                              get_capabilities_mock,
+                              log_mock):
+        ilo_object_mock = get_ilo_object_mock.return_value
+        properties = {'memory_mb': '512', 'local_gb': 10,
+                      'cpus': '1', 'cpu_arch': 'x86_64'}
+        macs = {'NIC.LOM.1.1': 'aa:aa:aa:aa:aa:aa'}
+        capabilities = {'server_model': 'Gen10'}
+        result = {'properties': properties, 'macs': macs}
+        get_essential_mock.return_value = result
+        get_capabilities_mock.return_value = capabilities
+        power_mock.return_value = states.POWER_ON
+        with task_manager.acquire(self.context, self.node.uuid,
+                                  shared=False) as task:
+            expected_properties = {'memory_mb': '512', 'local_gb': 10,
+                                   'cpus': '1', 'cpu_arch': 'x86_64',
+                                   'capabilities': 'server_model:Gen10'}
+            task.driver.inspect.inspect_hardware(task)
+            self.assertEqual(expected_properties, task.node.properties)
+            power_mock.assert_called_once_with(mock.ANY, task)
+            get_essential_mock.assert_called_once_with(task.node,
+                                                       ilo_object_mock)
+            self.assertFalse(log_mock.called)
+            get_capabilities_mock.assert_called_once_with(task.node,
+                                                          ilo_object_mock)
+            create_port_mock.assert_called_once_with(task, macs)
+
     @mock.patch.object(ilo_inspect, '_get_capabilities', spec_set=True,
                        autospec=True)
     @mock.patch.object(inspect_utils, 'create_ports_if_not_exist',
@@ -151,7 +235,7 @@ class IloInspectTestCase(test_common.BaseIloTest):
         properties = {'memory_mb': '512', 'local_gb': '10',
                       'cpus': '1', 'cpu_arch': 'x86_64'}
         macs = {'Port 1': 'aa:aa:aa:aa:aa:aa', 'Port 2': 'bb:bb:bb:bb:bb:bb'}
-        capabilities = ''
+        capabilities = {}
         result = {'properties': properties, 'macs': macs}
         get_essential_mock.return_value = result
         get_capabilities_mock.return_value = capabilities
