@@ -498,8 +498,9 @@ class IRMCDeployPrivateMethodsTestCase(test_common.BaseIRMCTest):
                 '/remote_image_share_root/'
                 "boot-%s.iso" % self.node.uuid,
                 'kernel_uuid', 'ramdisk_uuid',
-                '02f9d414-2ce0-4cf5-b48f-dbc1bf678f55',
-                'root-uuid', 'kernel-params', 'uefi')
+                deploy_iso_href='02f9d414-2ce0-4cf5-b48f-dbc1bf678f55',
+                root_uuid='root-uuid', kernel_params='kernel-params',
+                boot_mode='uefi')
             task.node.refresh()
             self.assertEqual("boot-%s.iso" % self.node.uuid,
                              task.node.driver_internal_info['irmc_boot_iso'])
@@ -680,7 +681,7 @@ class IRMCDeployPrivateMethodsTestCase(test_common.BaseIRMCTest):
             _get_iso_name_mock.assert_has_calls(
                 [mock.call(task.node, label='deploy'),
                  mock.call(task.node, label='rescue')])
-            self.assertTrue(_remove_share_file_mock.call_count, 3)
+            self.assertEqual(3, _remove_share_file_mock.call_count)
             _remove_share_file_mock.assert_has_calls(
                 [mock.call(_get_floppy_image_name_mock(task.node)),
                  mock.call(_get_iso_name_mock(task.node, label='deploy')),
