@@ -20,13 +20,14 @@ import time
 
 import mock
 from oslo_config import cfg
-from pysnmp.entity.rfc3413.oneliner import cmdgen
 from pysnmp import error as snmp_error
+from pysnmp import hlapi as pysnmp
 
 from ironic.common import exception
 from ironic.common import states
 from ironic.conductor import task_manager
 from ironic.drivers.modules import snmp
+from ironic.drivers.modules.snmp import SNMPDriverAuto
 from ironic.tests import base
 from ironic.tests.unit.db import base as db_base
 from ironic.tests.unit.db import utils as db_utils
@@ -36,196 +37,218 @@ CONF = cfg.CONF
 INFO_DICT = db_utils.get_test_snmp_info()
 
 
-@mock.patch.object(cmdgen, 'CommandGenerator', autospec=True)
 class SNMPClientTestCase(base.TestCase):
     def setUp(self):
         super(SNMPClientTestCase, self).setUp()
         self.address = '1.2.3.4'
         self.port = '6700'
-        self.oid = 'oid'
+        self.oid = (1, 3, 6, 1, 1, 1, 0)
         self.value = 'value'
 
-    def test___init__(self, mock_cmdgen):
+    @mock.patch.object(pysnmp, 'SnmpEngine', autospec=True)
+    def test___init__(self, mock_snmpengine):
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V1)
-        mock_cmdgen.assert_called_once_with()
+        mock_snmpengine.assert_called_once_with()
         self.assertEqual(self.address, client.address)
         self.assertEqual(self.port, client.port)
         self.assertEqual(snmp.SNMP_V1, client.version)
-        self.assertIsNone(client.community)
+        self.assertIsNone(client.read_community)
+        self.assertIsNone(client.write_community)
         self.assertNotIn('user', client.__dict__)
-        self.assertEqual(mock_cmdgen.return_value, client.cmd_gen)
+        self.assertEqual(mock_snmpengine.return_value, client.snmp_engine)
 
-    @mock.patch.object(cmdgen, 'CommunityData', autospec=True)
-    def test__get_auth_v1(self, mock_community, mock_cmdgen):
-        client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V1)
+    @mock.patch.object(pysnmp, 'CommunityData', autospec=True)
+    def test__get_auth_v1_read(self, mock_community):
+        client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V1,
+                                 read_community='public',
+                                 write_community='private')
         client._get_auth()
-        mock_cmdgen.assert_called_once_with()
-        mock_community.assert_called_once_with(client.community, mpModel=0)
+        mock_community.assert_called_once_with(client.read_community,
+                                               mpModel=0)
 
-    @mock.patch.object(cmdgen, 'UsmUserData', autospec=True)
-    def test__get_auth_v3(self, mock_user, mock_cmdgen):
+    @mock.patch.object(pysnmp, 'CommunityData', autospec=True)
+    def test__get_auth_v1_write(self, mock_community):
+        client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V1,
+                                 read_community='public',
+                                 write_community='private')
+        client._get_auth(write_mode=True)
+        mock_community.assert_called_once_with(client.write_community,
+                                               mpModel=0)
+
+    @mock.patch.object(pysnmp, 'UsmUserData', autospec=True)
+    def test__get_auth_v3(self, mock_user):
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
         client._get_auth()
-        mock_cmdgen.assert_called_once_with()
         mock_user.assert_called_once_with(
             client.user,
             authKey=client.auth_key,
             authProtocol=client.auth_proto,
             privKey=client.priv_key,
             privProtocol=client.priv_proto,
-            contextEngineId=client.context_engine_id,
-            contextName=client.context_name
         )
 
-    @mock.patch.object(cmdgen, 'UdpTransportTarget', autospec=True)
-    def test__get_transport(self, mock_transport, mock_cmdgen):
+    @mock.patch.object(pysnmp, 'ContextData', autospec=True)
+    def test__get_context(self, mock_context):
+        client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V1)
+        client._get_context()
+        mock_context.assert_called_once_with(None, '')
+
+    @mock.patch.object(pysnmp, 'UdpTransportTarget', autospec=True)
+    def test__get_transport(self, mock_transport):
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
         client._get_transport()
-        mock_cmdgen.assert_called_once_with()
         mock_transport.assert_called_once_with(
             (client.address, client.port),
             retries=CONF.snmp.udp_transport_retries,
             timeout=CONF.snmp.udp_transport_timeout)
 
-    @mock.patch.object(cmdgen, 'UdpTransportTarget', autospec=True)
-    def test__get_transport_err(self, mock_transport, mock_cmdgen):
+    @mock.patch.object(pysnmp, 'UdpTransportTarget', autospec=True)
+    def test__get_transport_err(self, mock_transport):
         mock_transport.side_effect = snmp_error.PySnmpError
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
         self.assertRaises(snmp_error.PySnmpError, client._get_transport)
-        mock_cmdgen.assert_called_once_with()
         mock_transport.assert_called_once_with(
             (client.address, client.port),
             retries=CONF.snmp.udp_transport_retries,
             timeout=CONF.snmp.udp_transport_timeout)
 
-    @mock.patch.object(cmdgen, 'UdpTransportTarget', autospec=True)
-    def test__get_transport_custom_timeout(self, mock_transport, mock_cmdgen):
+    @mock.patch.object(pysnmp, 'UdpTransportTarget', autospec=True)
+    def test__get_transport_custom_timeout(self, mock_transport):
         self.config(udp_transport_timeout=2.0, group='snmp')
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
         client._get_transport()
-        mock_cmdgen.assert_called_once_with()
         mock_transport.assert_called_once_with((client.address, client.port),
                                                retries=5, timeout=2.0)
 
-    @mock.patch.object(cmdgen, 'UdpTransportTarget', autospec=True)
-    def test__get_transport_custom_retries(self, mock_transport, mock_cmdgen):
+    @mock.patch.object(pysnmp, 'UdpTransportTarget', autospec=True)
+    def test__get_transport_custom_retries(self, mock_transport):
         self.config(udp_transport_retries=10, group='snmp')
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
         client._get_transport()
-        mock_cmdgen.assert_called_once_with()
         mock_transport.assert_called_once_with((client.address, client.port),
                                                retries=10, timeout=1.0)
 
+    @mock.patch.object(pysnmp, 'getCmd', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_transport', autospec=True)
+    @mock.patch.object(snmp.SNMPClient, '_get_context', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_auth', autospec=True)
-    def test_get(self, mock_auth, mock_transport, mock_cmdgen):
+    def test_get(self, mock_auth, mock_context, mock_transport, mock_getcmd):
         var_bind = (self.oid, self.value)
-        mock_cmdgenerator = mock_cmdgen.return_value
-        mock_cmdgenerator.getCmd.return_value = ("", None, 0, [var_bind])
+        mock_getcmd.return_value = iter([("", None, 0, [var_bind])])
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
         val = client.get(self.oid)
         self.assertEqual(var_bind[1], val)
-        mock_cmdgenerator.getCmd.assert_called_once_with(mock.ANY, mock.ANY,
-                                                         self.oid)
+        self.assertEqual(1, mock_getcmd.call_count)
 
+    @mock.patch.object(pysnmp, 'nextCmd', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_transport', autospec=True)
+    @mock.patch.object(snmp.SNMPClient, '_get_context', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_auth', autospec=True)
-    def test_get_next(self, mock_auth, mock_transport, mock_cmdgen):
+    def test_get_next(self, mock_auth, mock_context, mock_transport,
+                      mock_nextcmd):
         var_bind = (self.oid, self.value)
-        mock_cmdgenerator = mock_cmdgen.return_value
-        mock_cmdgenerator.nextCmd.return_value = (
-            "", None, 0, [[var_bind, var_bind]])
+        mock_nextcmd.return_value = iter([("", None, 0, [var_bind]),
+                                          ("", None, 0, [var_bind])])
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
         val = client.get_next(self.oid)
         self.assertEqual([self.value, self.value], val)
-        mock_cmdgenerator.nextCmd.assert_called_once_with(mock.ANY, mock.ANY,
-                                                          self.oid)
+        self.assertEqual(1, mock_nextcmd.call_count)
 
+    @mock.patch.object(pysnmp, 'getCmd', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_transport', autospec=True)
+    @mock.patch.object(snmp.SNMPClient, '_get_context', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_auth', autospec=True)
-    def test_get_err_transport(self, mock_auth, mock_transport, mock_cmdgen):
+    def test_get_err_transport(self, mock_auth, mock_context, mock_transport,
+                               mock_getcmd):
         mock_transport.side_effect = snmp_error.PySnmpError
         var_bind = (self.oid, self.value)
-        mock_cmdgenerator = mock_cmdgen.return_value
-        mock_cmdgenerator.getCmd.return_value = ("engine error", None, 0,
-                                                 [var_bind])
+        mock_getcmd.return_value = iter([("engine error", None,
+                                          0, [var_bind])])
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
         self.assertRaises(exception.SNMPFailure, client.get, self.oid)
-        self.assertFalse(mock_cmdgenerator.getCmd.called)
+        self.assertFalse(mock_getcmd.called)
 
+    @mock.patch.object(pysnmp, 'nextCmd', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_transport', autospec=True)
+    @mock.patch.object(snmp.SNMPClient, '_get_context', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_auth', autospec=True)
-    def test_get_next_err_transport(self, mock_auth, mock_transport,
-                                    mock_cmdgen):
+    def test_get_next_err_transport(self, mock_auth, mock_context,
+                                    mock_transport, mock_nextcmd):
         mock_transport.side_effect = snmp_error.PySnmpError
         var_bind = (self.oid, self.value)
-        mock_cmdgenerator = mock_cmdgen.return_value
-        mock_cmdgenerator.nextCmd.return_value = ("engine error", None, 0,
-                                                  [[var_bind, var_bind]])
+        mock_nextcmd.return_value = iter([("engine error", None, 0,
+                                           [var_bind])])
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
         self.assertRaises(exception.SNMPFailure, client.get_next, self.oid)
-        self.assertFalse(mock_cmdgenerator.nextCmd.called)
+        self.assertFalse(mock_nextcmd.called)
 
+    @mock.patch.object(pysnmp, 'getCmd', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_transport', autospec=True)
+    @mock.patch.object(snmp.SNMPClient, '_get_context', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_auth', autospec=True)
-    def test_get_err_engine(self, mock_auth, mock_transport, mock_cmdgen):
+    def test_get_err_engine(self, mock_auth, mock_context, mock_transport,
+                            mock_getcmd):
         var_bind = (self.oid, self.value)
-        mock_cmdgenerator = mock_cmdgen.return_value
-        mock_cmdgenerator.getCmd.return_value = ("engine error", None, 0,
-                                                 [var_bind])
+        mock_getcmd.return_value = iter([("engine error", None, 0,
+                                          [var_bind])])
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
         self.assertRaises(exception.SNMPFailure, client.get, self.oid)
-        mock_cmdgenerator.getCmd.assert_called_once_with(mock.ANY, mock.ANY,
-                                                         self.oid)
+        self.assertEqual(1, mock_getcmd.call_count)
 
+    @mock.patch.object(pysnmp, 'nextCmd', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_transport', autospec=True)
+    @mock.patch.object(snmp.SNMPClient, '_get_context', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_auth', autospec=True)
-    def test_get_next_err_engine(self, mock_auth, mock_transport, mock_cmdgen):
+    def test_get_next_err_engine(self, mock_auth, mock_context,
+                                 mock_transport, mock_nextcmd):
         var_bind = (self.oid, self.value)
-        mock_cmdgenerator = mock_cmdgen.return_value
-        mock_cmdgenerator.nextCmd.return_value = ("engine error", None, 0,
-                                                  [[var_bind, var_bind]])
+        mock_nextcmd.return_value = iter([("engine error", None, 0,
+                                           [var_bind])])
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
         self.assertRaises(exception.SNMPFailure, client.get_next, self.oid)
-        mock_cmdgenerator.nextCmd.assert_called_once_with(mock.ANY, mock.ANY,
-                                                          self.oid)
+        self.assertEqual(1, mock_nextcmd.call_count)
 
+    @mock.patch.object(pysnmp, 'setCmd', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_transport', autospec=True)
+    @mock.patch.object(snmp.SNMPClient, '_get_context', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_auth', autospec=True)
-    def test_set(self, mock_auth, mock_transport, mock_cmdgen):
+    def test_set(self, mock_auth, mock_context, mock_transport,
+                 mock_setcmd):
         var_bind = (self.oid, self.value)
-        mock_cmdgenerator = mock_cmdgen.return_value
-        mock_cmdgenerator.setCmd.return_value = ("", None, 0, [var_bind])
+        mock_setcmd.return_value = iter([("", None, 0,
+                                          [var_bind])])
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
         client.set(self.oid, self.value)
-        mock_cmdgenerator.setCmd.assert_called_once_with(mock.ANY, mock.ANY,
-                                                         var_bind)
+        self.assertEqual(1, mock_setcmd.call_count)
 
+    @mock.patch.object(pysnmp, 'setCmd', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_transport', autospec=True)
+    @mock.patch.object(snmp.SNMPClient, '_get_context', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_auth', autospec=True)
-    def test_set_err_transport(self, mock_auth, mock_transport, mock_cmdgen):
+    def test_set_err_transport(self, mock_auth, mock_context, mock_transport,
+                               mock_setcmd):
         mock_transport.side_effect = snmp_error.PySnmpError
         var_bind = (self.oid, self.value)
-        mock_cmdgenerator = mock_cmdgen.return_value
-        mock_cmdgenerator.setCmd.return_value = ("engine error", None, 0,
-                                                 [var_bind])
+        mock_setcmd.return_value = iter([("engine error", None, 0,
+                                          [var_bind])])
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
-        self.assertRaises(exception.SNMPFailure,
-                          client.set, self.oid, self.value)
-        self.assertFalse(mock_cmdgenerator.setCmd.called)
+        self.assertRaises(exception.SNMPFailure, client.set, self.oid,
+                          self.value)
+        self.assertFalse(mock_setcmd.called)
 
+    @mock.patch.object(pysnmp, 'setCmd', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_transport', autospec=True)
+    @mock.patch.object(snmp.SNMPClient, '_get_context', autospec=True)
     @mock.patch.object(snmp.SNMPClient, '_get_auth', autospec=True)
-    def test_set_err_engine(self, mock_auth, mock_transport, mock_cmdgen):
+    def test_set_err_engine(self, mock_auth, mock_context, mock_transport,
+                            mock_setcmd):
         var_bind = (self.oid, self.value)
-        mock_cmdgenerator = mock_cmdgen.return_value
-        mock_cmdgenerator.setCmd.return_value = ("engine error", None, 0,
-                                                 [var_bind])
+        mock_setcmd.return_value = iter([("engine error", None, 0,
+                                          [var_bind])])
         client = snmp.SNMPClient(self.address, self.port, snmp.SNMP_V3)
-        self.assertRaises(exception.SNMPFailure,
-                          client.set, self.oid, self.value)
-        mock_cmdgenerator.setCmd.assert_called_once_with(mock.ANY, mock.ANY,
-                                                         var_bind)
+        self.assertRaises(exception.SNMPFailure, client.set, self.oid,
+                          self.value)
+        self.assertEqual(1, mock_setcmd.call_count)
 
 
 class SNMPValidateParametersTestCase(db_base.DbTestCase):
@@ -244,7 +267,8 @@ class SNMPValidateParametersTestCase(db_base.DbTestCase):
         self.assertEqual(INFO_DICT['snmp_port'], str(info['port']))
         self.assertEqual(INFO_DICT['snmp_outlet'], str(info['outlet']))
         self.assertEqual(INFO_DICT['snmp_version'], info['version'])
-        self.assertEqual(INFO_DICT['snmp_community'], info['community'])
+        self.assertEqual(INFO_DICT['snmp_community'], info['read_community'])
+        self.assertEqual(INFO_DICT['snmp_community'], info['write_community'])
         self.assertNotIn('user', info)
 
     def test__parse_driver_info_apc(self):
@@ -310,7 +334,8 @@ class SNMPValidateParametersTestCase(db_base.DbTestCase):
         node = self._get_test_node(info)
         info = snmp._parse_driver_info(node)
         self.assertEqual('1', info['version'])
-        self.assertEqual('public', info['community'])
+        self.assertEqual('public', info['read_community'])
+        self.assertEqual('public', info['write_community'])
 
     def test__parse_driver_info_snmp_v2c(self):
         # Make sure SNMPv2c is parsed with a community string.
@@ -319,7 +344,42 @@ class SNMPValidateParametersTestCase(db_base.DbTestCase):
         node = self._get_test_node(info)
         info = snmp._parse_driver_info(node)
         self.assertEqual('2c', info['version'])
-        self.assertEqual('private', info['community'])
+        self.assertEqual('private', info['read_community'])
+        self.assertEqual('private', info['write_community'])
+
+    def test__parse_driver_info_read_write_community(self):
+        # Make sure separate read/write community name take precedence
+        info = db_utils.get_test_snmp_info(snmp_version='1',
+                                           snmp_community='impossible',
+                                           snmp_community_read='public',
+                                           snmp_community_write='private')
+        node = self._get_test_node(info)
+        info = snmp._parse_driver_info(node)
+        self.assertEqual('1', info['version'])
+        self.assertEqual('public', info['read_community'])
+        self.assertEqual('private', info['write_community'])
+
+    def test__parse_driver_info_read_community(self):
+        # Make sure separate read community name take precedence
+        info = db_utils.get_test_snmp_info(snmp_version='1',
+                                           snmp_community='foo',
+                                           snmp_community_read='bar')
+        node = self._get_test_node(info)
+        info = snmp._parse_driver_info(node)
+        self.assertEqual('1', info['version'])
+        self.assertEqual('bar', info['read_community'])
+        self.assertEqual('foo', info['write_community'])
+
+    def test__parse_driver_info_write_community(self):
+        # Make sure separate write community name take precedence
+        info = db_utils.get_test_snmp_info(snmp_version='1',
+                                           snmp_community='foo',
+                                           snmp_community_write='bar')
+        node = self._get_test_node(info)
+        info = snmp._parse_driver_info(node)
+        self.assertEqual('1', info['version'])
+        self.assertEqual('foo', info['read_community'])
+        self.assertEqual('bar', info['write_community'])
 
     def test__parse_driver_info_snmp_v3(self):
         # Make sure SNMPv3 is parsed with user string.
@@ -539,7 +599,8 @@ class SNMPValidateParametersTestCase(db_base.DbTestCase):
         node = self._get_test_node(info)
         info = snmp._parse_driver_info(node)
         self.assertEqual('1', info['version'])
-        self.assertEqual(INFO_DICT['snmp_community'], info['community'])
+        self.assertEqual(INFO_DICT['snmp_community'], info['read_community'])
+        self.assertEqual(INFO_DICT['snmp_community'], info['write_community'])
 
     def test__parse_driver_info_invalid_version(self):
         # Make sure exception is raised when version is invalid.
@@ -612,6 +673,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
     def setUp(self):
         super(SNMPDeviceDriverTestCase, self).setUp()
         self.config(enabled_power_interfaces=['fake', 'snmp'])
+        snmp._memoized = {}
         self.node = obj_utils.get_test_node(
             self.context,
             power_interface='snmp',
@@ -1289,6 +1351,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
             mock_client = mock_get_client.return_value
             mock_client.reset_mock()
             mock_client.get.return_value = sys_obj_oid
+            snmp._memoized.clear()
             self._update_driver_info(snmp_driver="auto")
             driver = snmp._get_driver(self.node)
 
@@ -1309,7 +1372,8 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
             mock_client = mock_get_client.return_value
             mock_client.reset_mock()
             mock_client.get.return_value = sys_obj_oid
-            self._update_driver_info(snmp_driver="auto")
+            snmp._memoized.clear()
+            self._update_driver_info(snmp_driver="auto",)
             driver = snmp._get_driver(self.node)
 
             second_node = obj_utils.get_test_node(
@@ -1329,7 +1393,8 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
             mock_client = mock_get_client.return_value
             mock_client.reset_mock()
             mock_client.get.return_value = sys_obj_oid
-            self._update_driver_info(snmp_driver="auto")
+            snmp._memoized.clear()
+            self._update_driver_info(snmp_driver="auto",)
             driver = snmp._get_driver(self.node)
 
             second_node = obj_utils.get_test_node(
@@ -1351,6 +1416,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
             mock_client = mock_get_client.return_value
             mock_client.reset_mock()
             mock_client.get.return_value = sys_obj_oid
+            snmp._memoized.clear()
             self._update_driver_info(snmp_driver="auto")
             driver = snmp._get_driver(self.node)
 
@@ -1373,6 +1439,7 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
             mock_client = mock_get_client.return_value
             mock_client.reset_mock()
             mock_client.get.side_effect = [sys_obj_oid, sys_obj_oid]
+            snmp._memoized.clear()
             self._update_driver_info(snmp_driver="auto")
             driver = snmp._get_driver(self.node)
 
@@ -1524,6 +1591,49 @@ class SNMPDeviceDriverTestCase(db_base.DbTestCase):
     def test_baytech_mrp27_power_reset(self, mock_get_client):
         self._test_simple_device_power_reset('baytech_mrp27', mock_get_client)
 
+    def test_auto_power_on_cached_driver(self, mock_get_client):
+        mock_client = mock_get_client.return_value
+        mock_client.reset_mock()
+        mock_client.get.return_value = (1, 3, 6, 1, 4, 1, 318, 1, 1, 4)
+        self._update_driver_info(snmp_driver="auto")
+
+        for i in range(5):
+            snmp._get_driver(self.node)
+
+        mock_client.get.assert_called_once_with(SNMPDriverAuto.SYS_OBJ_OID)
+
+    @mock.patch.object(snmp.SNMPDriverAPCRackPDU, "_snmp_power_on")
+    def test_snmp_auto_cache_supports_pdu_replacement(
+            self, broken_pdu_power_on_mock, mock_get_client):
+
+        broken_pdu_exception = exception.SNMPFailure(operation=1, error=2)
+        broken_pdu_power_on_mock.side_effect = broken_pdu_exception
+
+        broken_pdu_oid = (1, 3, 6, 1, 4, 1, 318, 1, 1, 12)
+        hashable_node_info = frozenset(
+            {('address', '1.2.3.4'), ('port', 161), ('community', 'public'),
+             ('version', '1'), ('driver', 'auto')})
+        snmp._memoized = {hashable_node_info: broken_pdu_oid}
+
+        self._update_driver_info(snmp_driver="auto")
+
+        mock_client = mock_get_client.return_value
+        mock_client.get.return_value = broken_pdu_oid
+
+        driver = snmp._get_driver(self.node)
+
+        mock_client.reset_mock()
+        replacement_pdu_oid = (1, 3, 6, 1, 4, 1, 318, 1, 1, 4)
+        mock_client.get.side_effect = [replacement_pdu_oid,
+                                       driver.driver.value_power_on]
+
+        pstate = driver.power_on()
+
+        mock_client.set.assert_called_once_with(
+            driver.driver.oid, driver.driver.value_power_on)
+
+        self.assertEqual(states.POWER_ON, pstate)
+
 
 @mock.patch.object(snmp, '_get_driver', autospec=True)
 class SNMPDriverTestCase(db_base.DbTestCase):
