@@ -1,4 +1,4 @@
-# Copyright (c) 2017 Dell Inc. or its subsidiaries.
+# Copyright (c) 2017-2019 Dell Inc. or its subsidiaries.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,14 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import inspect
-
-import mock
-from oslo_utils import importutils
-
-from ironic.common import exception
 from ironic.conductor import task_manager
-from ironic.drivers import drac as drac_drivers
 from ironic.drivers.modules import agent
 from ironic.drivers.modules import drac
 from ironic.drivers.modules import inspector
@@ -32,10 +25,23 @@ from ironic.tests.unit.db import base as db_base
 from ironic.tests.unit.objects import utils as obj_utils
 
 
-class BaseIDRACTestCase(db_base.DbTestCase):
+class IDRACHardwareTestCase(db_base.DbTestCase):
 
     def setUp(self):
-        super(BaseIDRACTestCase, self).setUp()
+        super(IDRACHardwareTestCase, self).setUp()
+        self.config(enabled_hardware_types=['idrac'],
+                    enabled_management_interfaces=[
+                        'idrac', 'idrac-redfish', 'idrac-wsman'],
+                    enabled_power_interfaces=[
+                        'idrac', 'idrac-redfish', 'idrac-wsman'],
+                    enabled_inspect_interfaces=[
+                        'idrac', 'idrac-redfish', 'idrac-wsman', 'inspector',
+                        'no-inspect'],
+                    enabled_network_interfaces=['flat', 'neutron', 'noop'],
+                    enabled_raid_interfaces=[
+                        'idrac', 'idrac-wsman', 'no-raid'],
+                    enabled_vendor_interfaces=[
+                        'idrac', 'idrac-wsman', 'no-vendor'])
 
     def _validate_interfaces(self, driver, **kwargs):
         self.assertIsInstance(
@@ -46,69 +52,45 @@ class BaseIDRACTestCase(db_base.DbTestCase):
             kwargs.get('deploy', iscsi_deploy.ISCSIDeploy))
         self.assertIsInstance(
             driver.management,
-            kwargs.get('management', drac.management.DracManagement))
+            kwargs.get('management', drac.management.DracWSManManagement))
         self.assertIsInstance(
             driver.power,
-            kwargs.get('power', drac.power.DracPower))
+            kwargs.get('power', drac.power.DracWSManPower))
 
-        # Console interface of iDRAC classic drivers is None.
-        console_interface = kwargs.get('console', None)
-
-        # None is not a class or type.
-        if inspect.isclass(console_interface):
-            self.assertIsInstance(driver.console, console_interface)
-        else:
-            self.assertIs(driver.console, console_interface)
+        self.assertIsInstance(
+            driver.console,
+            kwargs.get('console', noop.NoConsole))
 
         self.assertIsInstance(
             driver.inspect,
-            kwargs.get('inspect', drac.inspect.DracInspect))
+            kwargs.get('inspect', drac.inspect.DracWSManInspect))
 
-        # iDRAC classic drivers do not have a network interface.
-        if 'network' in driver.all_interfaces:
-            self.assertIsInstance(
-                driver.network,
-                kwargs.get('network', flat_net.FlatNetwork))
+        self.assertIsInstance(
+            driver.network,
+            kwargs.get('network', flat_net.FlatNetwork))
 
         self.assertIsInstance(
             driver.raid,
-            kwargs.get('raid', drac.raid.DracRAID))
+            kwargs.get('raid', drac.raid.DracWSManRAID))
 
-        # iDRAC classic drivers do not have a storage interface.
-        if 'storage' in driver.all_interfaces:
-            self.assertIsInstance(
-                driver.storage,
-                kwargs.get('storage', noop_storage.NoopStorage))
+        self.assertIsInstance(
+            driver.storage,
+            kwargs.get('storage', noop_storage.NoopStorage))
 
         self.assertIsInstance(
             driver.vendor,
-            kwargs.get('vendor', drac.vendor_passthru.DracVendorPassthru))
-
-
-class IDRACHardwareTestCase(BaseIDRACTestCase):
-
-    def setUp(self):
-        super(IDRACHardwareTestCase, self).setUp()
-        self.config(enabled_hardware_types=['idrac'],
-                    enabled_management_interfaces=['idrac'],
-                    enabled_power_interfaces=['idrac'],
-                    enabled_inspect_interfaces=[
-                        'idrac', 'inspector', 'no-inspect'],
-                    enabled_network_interfaces=['flat', 'neutron', 'noop'],
-                    enabled_raid_interfaces=['idrac', 'no-raid'],
-                    enabled_vendor_interfaces=['idrac', 'no-vendor'])
+            kwargs.get('vendor', drac.vendor_passthru.DracWSManVendorPassthru))
 
     def test_default_interfaces(self):
         node = obj_utils.create_test_node(self.context, driver='idrac')
         with task_manager.acquire(self.context, node.id) as task:
-            self._validate_interfaces(task.driver, console=noop.NoConsole)
+            self._validate_interfaces(task.driver)
 
     def test_override_with_inspector(self):
         node = obj_utils.create_test_node(self.context, driver='idrac',
                                           inspect_interface='inspector')
         with task_manager.acquire(self.context, node.id) as task:
             self._validate_interfaces(task.driver,
-                                      console=noop.NoConsole,
                                       inspect=inspector.Inspector)
 
     def test_override_with_agent(self):
@@ -117,7 +99,6 @@ class IDRACHardwareTestCase(BaseIDRACTestCase):
                                           inspect_interface='inspector')
         with task_manager.acquire(self.context, node.id) as task:
             self._validate_interfaces(task.driver,
-                                      console=noop.NoConsole,
                                       deploy=agent.AgentDeploy,
                                       inspect=inspector.Inspector)
 
@@ -126,7 +107,6 @@ class IDRACHardwareTestCase(BaseIDRACTestCase):
                                           raid_interface='no-raid')
         with task_manager.acquire(self.context, node.id) as task:
             self._validate_interfaces(task.driver,
-                                      console=noop.NoConsole,
                                       raid=noop.NoRAID)
 
     def test_override_no_vendor(self):
@@ -134,31 +114,38 @@ class IDRACHardwareTestCase(BaseIDRACTestCase):
                                           vendor_interface='no-vendor')
         with task_manager.acquire(self.context, node.id) as task:
             self._validate_interfaces(task.driver,
-                                      console=noop.NoConsole,
                                       vendor=noop.NoVendor)
 
+    def test_override_with_idrac(self):
+        node = obj_utils.create_test_node(self.context, driver='idrac',
+                                          management_interface='idrac',
+                                          power_interface='idrac',
+                                          inspect_interface='idrac',
+                                          raid_interface='idrac',
+                                          vendor_interface='idrac')
+        with task_manager.acquire(self.context, node.id) as task:
+            self._validate_interfaces(
+                task.driver,
+                management=drac.management.DracManagement,
+                power=drac.power.DracPower,
+                inspect=drac.inspect.DracInspect,
+                raid=drac.raid.DracRAID,
+                vendor=drac.vendor_passthru.DracVendorPassthru)
 
-@mock.patch.object(importutils, 'try_import', spec_set=True, autospec=True)
-class DracClassicDriversTestCase(BaseIDRACTestCase):
+    def test_override_with_redfish_management_and_power(self):
+        node = obj_utils.create_test_node(self.context, driver='idrac',
+                                          management_interface='idrac-redfish',
+                                          power_interface='idrac-redfish')
+        with task_manager.acquire(self.context, node.id) as task:
+            self._validate_interfaces(
+                task.driver,
+                management=drac.management.DracRedfishManagement,
+                power=drac.power.DracRedfishPower)
 
-    def setUp(self):
-        super(DracClassicDriversTestCase, self).setUp()
-
-    def test_pxe_drac_driver(self, mock_try_import):
-        mock_try_import.return_value = True
-
-        driver = drac_drivers.PXEDracDriver()
-        self._validate_interfaces(driver)
-
-    def test___init___try_import_dracclient_failure(self, mock_try_import):
-        mock_try_import.return_value = False
-
-        self.assertRaises(exception.DriverLoadError,
-                          drac_drivers.PXEDracDriver)
-
-    def test_pxe_drac_inspector_driver(self, mock_try_import):
-        self.config(enabled=True, group='inspector')
-        mock_try_import.return_value = True
-
-        driver = drac_drivers.PXEDracInspectorDriver()
-        self._validate_interfaces(driver, inspect=inspector.Inspector)
+    def test_override_with_redfish_inspect(self):
+        node = obj_utils.create_test_node(self.context, driver='idrac',
+                                          inspect_interface='idrac-redfish')
+        with task_manager.acquire(self.context, node.id) as task:
+            self._validate_interfaces(
+                task.driver,
+                inspect=drac.inspect.DracRedfishInspect)
