@@ -30,26 +30,17 @@ DRACCLIENT_CLIENT_MOD_SPEC = (
 DRACCLIENT_CONSTANTS_MOD_SPEC = (
     'POWER_OFF',
     'POWER_ON',
-    'REBOOT'
+    'REBOOT',
+    'RebootRequired'
 )
 
-# ironic_inspector
-IRONIC_INSPECTOR_CLIENT_SPEC = (
-    'ClientV1',
+DRACCLIENT_CONSTANTS_REBOOT_REQUIRED_MOD_SPEC = (
+    'true',
+    'optional',
+    'false'
 )
 
 
-class InspectorClientV1Specs(object):
-    def __init__(self, session, inspector_url, api_version):
-        pass
-
-    def introspect(self, uuid):
-        pass
-
-    def get_status(self, uuid):
-        pass
-
-
 # proliantutils
 PROLIANTUTILS_SPEC = (
     'exception',
@@ -145,6 +136,8 @@ SUSHY_SPEC = (
     'STATE_ENABLED',
     'STATE_DISABLED',
     'STATE_ABSENT',
+    'VIRTUAL_MEDIA_CD',
+    'VIRTUAL_MEDIA_FLOPPY',
 )
 
 SUSHY_AUTH_SPEC = (
