@@ -90,23 +90,18 @@ if not dracclient:
         POWER_OFF=mock.sentinel.POWER_OFF,
         POWER_ON=mock.sentinel.POWER_ON,
         REBOOT=mock.sentinel.REBOOT)
+    dracclient.constants.RebootRequired = mock.MagicMock(
+        spec_set=mock_specs.DRACCLIENT_CONSTANTS_REBOOT_REQUIRED_MOD_SPEC,
+        true=mock.sentinel.true,
+        optional=mock.sentinel.optional,
+        false=mock.sentinel.false)
+
     sys.modules['dracclient'] = dracclient
     sys.modules['dracclient.client'] = dracclient.client
     sys.modules['dracclient.constants'] = dracclient.constants
     sys.modules['dracclient.exceptions'] = dracclient.exceptions
     dracclient.exceptions.BaseClientException = type('BaseClientException',
                                                      (Exception,), {})
-
-    dracclient.exceptions.DRACRequestFailed = type(
-        'DRACRequestFailed', (dracclient.exceptions.BaseClientException,), {})
-
-    class DRACOperationFailed(dracclient.exceptions.DRACRequestFailed):
-        def __init__(self, **kwargs):
-            super(DRACOperationFailed, self).__init__(
-                'DRAC operation failed. Messages: %(drac_messages)s' % kwargs)
-
-    dracclient.exceptions.DRACOperationFailed = DRACOperationFailed
-
     # Now that the external library has been mocked, if anything had already
     # loaded any of the drivers, reload them.
     if 'ironic.drivers.modules.drac' in sys.modules:
@@ -168,49 +163,12 @@ irmc_boot.check_share_fs_mounted_patcher = mock.patch(
 irmc_boot.check_share_fs_mounted_patcher.return_value = None
 
 
-ironic_inspector_client = importutils.try_import('ironic_inspector_client')
-if not ironic_inspector_client:
-    ironic_inspector_client = mock.MagicMock(
-        spec_set=mock_specs.IRONIC_INSPECTOR_CLIENT_SPEC)
-    ironic_inspector_client.ClientV1 = mock_specs.InspectorClientV1Specs
-    sys.modules['ironic_inspector_client'] = ironic_inspector_client
-    if 'ironic.drivers.modules.inspector' in sys.modules:
-        six.moves.reload_module(
-            sys.modules['ironic.drivers.modules.inspector'])
-
-
 class MockKwargsException(Exception):
     def __init__(self, *args, **kwargs):
         super(MockKwargsException, self).__init__(*args)
         self.kwargs = kwargs
 
 
-ucssdk = importutils.try_import('UcsSdk')
-if not ucssdk:
-    ucssdk = mock.MagicMock()
-    sys.modules['UcsSdk'] = ucssdk
-    sys.modules['UcsSdk.utils'] = ucssdk.utils
-    sys.modules['UcsSdk.utils.power'] = ucssdk.utils.power
-    sys.modules['UcsSdk.utils.management'] = ucssdk.utils.management
-    sys.modules['UcsSdk.utils.exception'] = ucssdk.utils.exception
-    ucssdk.utils.exception.UcsOperationError = (
-        type('UcsOperationError', (MockKwargsException,), {}))
-    ucssdk.utils.exception.UcsConnectionError = (
-        type('UcsConnectionError', (MockKwargsException,), {}))
-    if 'ironic.drivers.modules.ucs' in sys.modules:
-        six.moves.reload_module(
-            sys.modules['ironic.drivers.modules.ucs'])
-
-imcsdk = importutils.try_import('ImcSdk')
-if not imcsdk:
-    imcsdk = mock.MagicMock()
-    imcsdk.ImcException = Exception
-    sys.modules['ImcSdk'] = imcsdk
-    if 'ironic.drivers.modules.cimc' in sys.modules:
-        six.moves.reload_module(
-            sys.modules['ironic.drivers.modules.cimc'])
-
-
 sushy = importutils.try_import('sushy')
 if not sushy:
     sushy = mock.MagicMock(
@@ -241,6 +199,8 @@ if not sushy:
         STATE_ENABLED='enabled',
         STATE_DISABLED='disabled',
         STATE_ABSENT='absent',
+        VIRTUAL_MEDIA_CD='cd',
+        VIRTUAL_MEDIA_FLOPPY='floppy',
     )
 
     sys.modules['sushy'] = sushy
