@@ -677,31 +677,31 @@ class TestObject(_LocalTest, _TestObject):
 # version bump. It is an MD5 hash of the object fields and remotable methods.
 # The fingerprint values should only be changed if there is a version bump.
 expected_object_fingerprints = {
-    'Node': '1.29-7af860bb4017751104558139c52a1327',
+    'Node': '1.32-525750e76f07b62142ed5297334b7832',
     'MyObj': '1.5-9459d30d6954bffc7a9afd347a807ca6',
     'Chassis': '1.3-d656e039fd8ae9f34efc232ab3980905',
-    'Port': '1.8-898a47921f4a1f53fcdddd4eeb179e0b',
+    'Port': '1.9-0cb9202a4ec442e8c0d87a324155eaaf',
     'Portgroup': '1.4-71923a81a86743b313b190f5c675e258',
     'Conductor': '1.3-d3f53e853b4d58cae5bfbd9a8341af4a',
     'EventType': '1.1-aa2ba1afd38553e3880c267404e8d370',
     'NotificationPublisher': '1.0-51a09397d6c0687771fb5be9a999605d',
-    'NodePayload': '1.11-f323602c2e9c3edbf2a5567eca087ff5',
+    'NodePayload': '1.13-18a34d461ef7d5dbc1c3e5a55fcb867a',
     'NodeSetPowerStateNotification': '1.0-59acc533c11d306f149846f922739c15',
-    'NodeSetPowerStatePayload': '1.11-b61e66ef9d100a2cc564d16b12810855',
+    'NodeSetPowerStatePayload': '1.13-4f96e52568e058e3fd6ffc9b0cf15764',
     'NodeCorrectedPowerStateNotification':
         '1.0-59acc533c11d306f149846f922739c15',
-    'NodeCorrectedPowerStatePayload': '1.11-e6e32a38ca655509802ac3c6d8bc17f6',
+    'NodeCorrectedPowerStatePayload': '1.13-929af354e7c3474520ce6162ee794717',
     'NodeSetProvisionStateNotification':
         '1.0-59acc533c11d306f149846f922739c15',
-    'NodeSetProvisionStatePayload': '1.11-d13cb3472eea163de5b0723a08e95d2c',
+    'NodeSetProvisionStatePayload': '1.13-fa15d2954961d8edcaba9d737a1cad91',
     'VolumeConnector': '1.0-3e0252c0ab6e6b9d158d09238a577d97',
     'VolumeTarget': '1.0-0b10d663d8dae675900b2c7548f76f5e',
     'ChassisCRUDNotification': '1.0-59acc533c11d306f149846f922739c15',
     'ChassisCRUDPayload': '1.0-dce63895d8186279a7dd577cffccb202',
     'NodeCRUDNotification': '1.0-59acc533c11d306f149846f922739c15',
-    'NodeCRUDPayload': '1.9-c5e57432274371f7fe32f269519033cf',
+    'NodeCRUDPayload': '1.11-f1c6a6b099e8e28f55378c448c033de0',
     'PortCRUDNotification': '1.0-59acc533c11d306f149846f922739c15',
-    'PortCRUDPayload': '1.2-233d259df442eb15cc584fae1fe81504',
+    'PortCRUDPayload': '1.3-21235916ed54a91b2a122f59571194e7',
     'NodeMaintenanceNotification': '1.0-59acc533c11d306f149846f922739c15',
     'NodeConsoleNotification': '1.0-59acc533c11d306f149846f922739c15',
     'PortgroupCRUDNotification': '1.0-59acc533c11d306f149846f922739c15',
@@ -714,6 +714,12 @@ expected_object_fingerprints = {
     'TraitList': '1.0-33a2e1bb91ad4082f9f63429b77c1244',
     'BIOSSetting': '1.0-fd4a791dc2139a7cc21cefbbaedfd9e7',
     'BIOSSettingList': '1.0-33a2e1bb91ad4082f9f63429b77c1244',
+    'Allocation': '1.0-25ebf609743cd3f332a4f80fcb818102',
+    'AllocationCRUDNotification': '1.0-59acc533c11d306f149846f922739c15',
+    'AllocationCRUDPayload': '1.0-a82389d019f37cfe54b50049f73911b3',
+    'DeployTemplate': '1.1-4e30c8e9098595e359bb907f095bf1a9',
+    'DeployTemplateCRUDNotification': '1.0-59acc533c11d306f149846f922739c15',
+    'DeployTemplateCRUDPayload': '1.0-200857e7e715f58a5b6d6b700ab73a3b',
 }
 
 
